/*------------------------------------------------------------------------------


Hello, this is the main WordPress admin CSS file.
All the important stuff is in here.


TABLE OF CONTENTS:
------------------
 1.0 - Text Elements
 2.0 - Forms
 3.0 - Actions
 4.0 - Notifications
 5.0 - TinyMCE
 6.0 - Admin Header
	6.1 - Favorites Menu
	6.2 - Screen Options Tabs
	6.3 - Help Menu
 7.0 - Main Navigation
 8.0 - Layout Blocks
 9.0 - Dashboard
10.0 - List Posts
	10.1 - Inline Editing
11.0 - Write/Edit Post Screen
	11.1 - Custom Fields
	11.2 - Post Revisions
12.0 - Categories
13.0 - Tags
14.0 - Media Screen
	14.1 - Media Uploader
	14.2 - Image Editor
15.0 - Comments Screen
16.0 - Themes
	16.1 - Custom Header
	16.2 - Custom Background
	16.3 - Tabbed Admin Screen Interface
17.0 - Plugins
18.0 - Users
19.0 - Tools
20.0 - Settings
21.0 - Admin Footer
22.0 - Misc
23.0 - Dead

------------------------------------------------------------------------*/

/* 2 column liquid layout */
#wpwrap {
	height: auto;
	min-height: 100%;
	width: 100%;
	position: relative;
}

#wpcontent {
	height: 100%;
}

#wpcontent,
#footer {
	margin-left: 165px;
}

#wpbody-content {
	padding-bottom: 65px;
}

.folded #wpcontent,
.folded #footer {
	margin-left: 52px;
}

#wpbody-content {
	float: left;
	width: 100%;
}

#adminmenuback,
#adminmenuwrap,
#adminmenu,
#adminmenu .wp-submenu,
#adminmenu .wp-submenu-wrap,
.folded #adminmenu .wp-has-current-submenu .wp-submenu {
	width: 145px;
}

#adminmenuback {
	position: absolute;
	top: 0;
	bottom: 0;
	z-index: -1;
}

#adminmenuwrap {
	float: left;
}

#adminmenu {
	clear: left;
	margin: 0;
	padding: 0;
	list-style: none;
}

.folded #adminmenuback,
.folded #adminmenuwrap,
.folded #adminmenu,
.folded #adminmenu li.menu-top {
	width: 32px;
}

/* inner 2 column liquid layout */
.inner-sidebar {
	float: right;
	clear: right;
	display: none;
	min-width: 281px;
	position: relative;
}

.columns-2 .inner-sidebar {
	margin-right: auto;
	width: 286px;
	display: block;
}

.inner-sidebar #side-sortables,
.columns-2 .inner-sidebar #side-sortables {
	min-height: 300px;
	width: 280px;
	padding: 0;
}

.has-right-sidebar .inner-sidebar {
	display: block;
}

.has-right-sidebar #post-body {
	float: left;
	clear: left;
	width: 100%;
	margin-right: -2000px;
}

.has-right-sidebar #post-body-content {
	margin-right: 300px;
}

#post-body-content {
	max-width: 850px;
	min-width: 465px;
}

.columns-1 #post-body-content,
.columns-2 #post-body-content {
	max-width: none;
}

#post-body-content #side-sortables.empty-container {
	border: 0 none;
	height: 0;
}

/* 2 columns main area */



#col-container,
#col-left,
#col-right {
	overflow: hidden;
	padding: 0;
	margin: 0;
}

#col-left {
	width: 35%;
}

#col-right {
	float: right;
	clear: right;
	width: 65%;
}

.col-wrap {
	padding: 0 7px;
}

/* utility classes */
.alignleft {
	float: left;
}

.alignright {
	float: right;
}

.textleft {
	text-align: left;
}

.textright {
	text-align: right;
}

.clear {
	clear: both;
}

/* Hide visually but not from screen readers */
.screen-reader-text,
.screen-reader-text span {
	position: absolute;
	left: -1000em;
	height: 1px;
	width: 1px;
	overflow: hidden;
}

.hidden,
.js .closed .inside,
.js .hide-if-js,
.no-js .hide-if-no-js {
	display: none;
}

/* include margin and padding in the width calculation of input and textarea */
input[type="text"],
input[type="password"],
textarea {
	-moz-box-sizing: border-box;
	-webkit-box-sizing: border-box;
	-ms-box-sizing: border-box; /* ie8 only */
	box-sizing: border-box;
}

input[type="checkbox"],
input[type="radio"] {
	vertical-align: middle;
}

/* general */
html,
body {
	height: 100%;
	margin: 0;
	padding: 0;
}

body {
	font-family: sans-serif;
	font-size: 12px;
	line-height: 1.4em;
	min-width: 600px;
}

body.iframe {
	min-width: 0;
}

body.login {
	background: #fbfbfb;
	min-width: 0;
}

td,
textarea,
input,
select {
	font-family: inherit;
	font-size: inherit;
	font-weight: inherit;
}

td,
textarea {
	line-height: inherit;
}

input,
select {
	line-height: 15px;
}

a,
input,
select {
	outline: 0;
}

blockquote,
q {
	quotes: none;
}

blockquote:before,
blockquote:after,
q:before,
q:after {
	content: '';
	content: none;
}

p {
	margin: 1em 0;
}

blockquote {
	margin: 1em;
}

label {
	cursor: pointer;
}

li,
dd {
	margin-bottom: 6px;
}

textarea,
input,
select {
	margin: 1px;
	padding: 3px;
}

h1,
h2,
h3,
h4,
h5,
h6 {
	display: block;
	font-weight: bold;
}

h1 {
	font-size: 2em;
	margin: .67em 0;
}

h2 {
	font-size: 1.5em;
	margin: .83em 0;
}

h3 {
	font-size: 1.17em;
	margin: 1em 0;
}

h4 {
	font-size: 1em;
	margin: 1.33em 0;
}

h5 {
	font-size: 0.83em;
	margin: 1.67em 0;
}

h6 {
	font-size: 0.67em;
	margin: 2.33em 0;
}

ul,
ol {
	padding: 0;
}

ul li,
ol li {
	list-style: none;
}

ul.ul-disc {
	list-style: disc outside;
}

ul.ul-square {
	list-style: square outside;
}

ol {
	list-style-type: decimal;
	margin-left: 2em;
}

ul.ul-disc,
ul.ul-square,
ol.ol-decimal {
	margin-left: 1.8em;
}

ul.ul-disc > li,
ul.ul-square > li,
ol.ol-decimal > li {
	margin: 0 0 0.5em;
}

.code,
code {
	font-family: Consolas, Monaco, monospace;
}

kbd,
code {
	padding: 1px 3px;
	margin: 0 1px;
	font-size: 11px;
}

.subsubsub {
	list-style: none;
	margin: 8px 0 5px;
	padding: 0;
	white-space: nowrap;
	font-size: 12px;
	float: left;
}

.subsubsub a {
	line-height: 2;
	padding: .2em;
	text-decoration: none;
}

.subsubsub a .count,
.subsubsub a.current .count {
	color: #999;
	font-weight: normal;
}

.subsubsub a.current {
	font-weight: bold;
	background: none;
	border: none;
}

.subsubsub li {
	display: inline;
	margin: 0;
	padding: 0;
}

.widefat,
div.updated,
div.error,
.wrap .add-new-h2,
textarea,
input[type="text"],
input[type="password"],
input[type="file"],
input[type="button"],
input[type="submit"],
input[type="reset"],
input[type="email"],
input[type="number"],
input[type="search"],
input[type="tel"],
input[type="url"],
select,
.tablenav .tablenav-pages a,
.tablenav-pages span.current,
#titlediv #title,
.postbox,
#postcustomstuff table,
#postcustomstuff input,
#postcustomstuff textarea,
.imgedit-menu div,
.plugin-update-tr .update-message,
#poststuff .inside .the-tagcloud,
.login form,
#login_error,
.login .message,
#menu-management .menu-edit,
.nav-menus-php .list-container,
.menu-item-handle,
.link-to-original,
.nav-menus-php .major-publishing-actions .form-invalid,
.press-this #message,
#TB_window,
.tbtitle,
.highlight,
.feature-filter,
#widget-list .widget-top,
.editwidget .widget-inside {
	-webkit-border-radius: 3px;
	border-radius: 3px;
	border-width: 1px;
	border-style: solid;
}

/* .widefat - main style for tables */
.widefat {
	border-spacing: 0;
	width: 100%;
	clear: both;
	margin: 0;
}

.widefat * {
	word-wrap: break-word;
}

.widefat a {
	text-decoration: none;
}

.widefat thead th:first-of-type {
	-webkit-border-top-left-radius: 3px;
	border-top-left-radius: 3px;
}
.widefat thead th:last-of-type {
	-webkit-border-top-right-radius: 3px;
	border-top-right-radius: 3px;
}
.widefat tfoot th:first-of-type {
	-webkit-border-bottom-left-radius: 3px;
	border-bottom-left-radius: 3px;
}
.widefat tfoot th:last-of-type {
	-webkit-border-bottom-right-radius: 3px;
	border-bottom-right-radius: 3px;
}

.widefat td,
.widefat th {
	border-width: 1px 0;
	border-style: solid;
}
.widefat tfoot th {
	border-bottom: none;
}

.widefat .no-items td {
	border-bottom-width: 0;
}

.widefat td {
	font-size: 12px;
	padding: 4px 7px 2px;
	vertical-align: top;
}

.widefat td p,
.widefat td ol,
.widefat td ul {
	font-size: 12px;
}

.widefat th {
	padding: 7px 7px 8px;
	text-align: left;
	line-height: 1.3em;
	font-size: 14px;
}

.widefat th input {
	margin: 0 0 0 8px;
	padding: 0;
	vertical-align: text-top;
}

.widefat .check-column {
	width: 2.2em;
	padding: 11px 0 0;
	vertical-align: top;
}

.widefat tbody th.check-column {
	padding: 9px 0 22px;
}

.widefat .num,
.column-comments,
.column-links,
.column-posts {
	text-align: center;
}

.widefat th#comments {
	vertical-align: middle;
}

.wrap {
	margin: 4px 15px 0 0;
}

div.updated,
div.error {
	padding: 0 0.6em;
	margin: 5px 15px 2px;
}

div.updated p,
div.error p {
	margin: 0.5em 0;
	padding: 2px;
}

.wrap div.updated,
.wrap div.error {
	margin: 5px 0 15px;
}

.wrap h2,
.subtitle {
	font-weight: normal;
	margin: 0;
	text-shadow: #fff 0 1px 0;
}

.wrap h2 {
	font-size: 23px;
	padding: 9px 15px 4px 0;
	line-height: 29px;
}

.subtitle {
	font-size: 14px;
	padding-left: 25px;
}

.wrap .add-new-h2 {
	font-family: sans-serif;
	margin-left: 4px;
	padding: 3px 8px;
	position: relative;
	top: -3px;
	text-decoration: none;
	font-size: 12px;
	border: 0 none;
}

.wrap h2.long-header {
	padding-right: 0;
}


/* =CSS 3 transitions
-------------------------------------------------------------- */
.fade-1000 {
	opacity: 0;
	-moz-transition-property: opacity;
	-moz-transition-duration: 1s;
	-webkit-transition-property: opacity;
	-webkit-transition-duration: 1s;
	-o-transition-property: opacity;
	-o-transition-duration: 1s;
	transition-property: opacity;
	transition-duration: 1s;
}

.fade-600 {
	opacity: 0;
	-moz-transition-property: opacity;
	-moz-transition-duration: 0.6s;
	-webkit-transition-property: opacity;
	-webkit-transition-duration: 0.6s;
	-o-transition-property: opacity;
	-o-transition-duration: 0.6s;
	transition-property: opacity;
	transition-duration: 0.6s;
}

.fade-400 {
	opacity: 0;
	-moz-transition-property: opacity;
	-moz-transition-duration: 0.4s;
	-webkit-transition-property: opacity;
	-webkit-transition-duration: 0.4s;
	-o-transition-property: opacity;
	-o-transition-duration: 0.4s;
	transition-property: opacity;
	transition-duration: 0.4s;
}

.fade-300 {
	opacity: 0;
	-moz-transition-property: opacity;
	-moz-transition-duration: 0.3s;
	-webkit-transition-property: opacity;
	-webkit-transition-duration: 0.3s;
	-o-transition-property: opacity;
	-o-transition-duration: 0.3s;
	transition-property: opacity;
	transition-duration: 0.3s;
}

.fade-trigger {
	opacity: 1;
}


/*------------------------------------------------------------------------------
  1.0 - Text Styles
------------------------------------------------------------------------------*/

div.sidebar-name h3,
#menu-management .nav-tab,
#dashboard_plugins h5,
a.rsswidget,
#dashboard_right_now td.b,
#dashboard-widgets h4,
.tool-box .title,
#poststuff h3,
.metabox-holder h3,
.pressthis a,
#your-profile legend,
.inline-edit-row fieldset span.title,
.inline-edit-row fieldset span.checkbox-title,
.tablenav .displaying-num,
.welcome-panel h3,
.widefat th,
#wphead h1,
.quicktags,
.search {
	font-family: Georgia, "Times New Roman", "Bitstream Charter", Times, serif;
}

h2 .nav-tab,
.wrap h2,
.subtitle,
.login form .input {
	font-family: "HelveticaNeue-Light", "Helvetica Neue Light", "Helvetica Neue", sans-serif;
}

.quicktags,
.search {
	font-size: 12px;
}

.icon32 {
	float: left;
	height: 34px;
	margin: 7px 8px 0 0;
	width: 36px;
}

.key-labels label {
	line-height: 24px;
}

.pre {
	/* http://www.longren.org/2006/09/27/wrapping-text-inside-pre-tags/ */
	white-space: pre-wrap; /* css-3 */
	white-space: -moz-pre-wrap !important; /* Mozilla, since 1999 */
	white-space: -pre-wrap; /* Opera 4-6 */
	white-space: -o-pre-wrap; /* Opera 7 */
	word-wrap: break-word; /* Internet Explorer 5.5+ */
}

.howto {
	font-style: italic;
	display: block;
	font-family: sans-serif;
}

p.install-help {
	margin: 8px 0;
	font-style: italic;
}


/*------------------------------------------------------------------------------
  2.0 - Forms
------------------------------------------------------------------------------*/


.wp-admin select {
	padding: 2px;
	height: 2em;
	max-width: 100%;
}

.wp-admin select[multiple] {
	height: auto;
}

select option {
	padding: 2px;
}

.submit {
	padding: 1.5em 0;
	margin: 5px 0;
	-webkit-border-bottom-left-radius: 3px;
	-webkit-border-bottom-right-radius: 3px;
	border-bottom-left-radius: 3px;
	border-bottom-right-radius: 3px;
}

form p.submit a.cancel:hover {
	text-decoration: none;
}

.submit input,
.button,
input.button,
.button-primary,
input.button-primary,
.button-secondary,
input.button-secondary,
.button-highlighted,
input.button-highlighted,
#postcustomstuff .submit input {
	text-decoration: none;
	font-size: 12px !important;
	line-height: 13px;
	padding: 3px 8px;
	cursor: pointer;
	border-width: 1px;
	border-style: solid;
	-webkit-border-radius: 11px;
	border-radius: 11px;
	-moz-box-sizing: content-box;
	-webkit-box-sizing: content-box;
	box-sizing: content-box;
}

#minor-publishing-actions input,
#major-publishing-actions input,
#minor-publishing-actions .preview {
	min-width: 80px;
	text-align: center;
}

textarea.all-options,
input.all-options {
	width: 250px;
}

input.large-text,
textarea.large-text {
	width: 99%;
}

input.regular-text,
#adduser .form-field input {
	width: 25em;
}

input.small-text {
	width: 50px;
}

#doaction,
#doaction2,
#post-query-submit {
	margin-right: 8px;
}

.tablenav select[name="action"],
.tablenav select[name="action2"] {
	width: 130px;
}

.tablenav select[name="m"] {
	width: 155px;
}

.tablenav select#cat {
	width: 170px;
}

#wpcontent option {
	padding: 2px;
}

#timezone_string option {
	margin-left: 1em;
}

label,
#your-profile label + a {
	vertical-align: middle;
}

#misc-publishing-actions label {
	vertical-align: baseline;
}

#pass-strength-result {
	border-style: solid;
	border-width: 1px;
	float: left;
	margin: 13px 5px 5px 1px;
	padding: 3px 5px;
	text-align: center;
	width: 200px;
	display: none;
}
.indicator-hint {
	padding-top: 8px;
}

p.search-box {
	float: right;
	margin: 0;
}


/*------------------------------------------------------------------------------
  3.0 - Actions
------------------------------------------------------------------------------*/

#major-publishing-actions {
	padding: 10px 10px 8px;
	clear: both;
	border-top: none;
}

#delete-action {
	line-height: 25px;
	vertical-align: middle;
	text-align: left;
	float: left;
}

#publishing-action {
	text-align: right;
	float: right;
	line-height: 23px;
}

#post-body #minor-publishing {
	padding-bottom: 10px;
}

#post-body #misc-publishing-actions {
	padding: 0;
}

#post-body .misc-pub-section {
	border-right-width: 1px;
	border-right-style: solid;
	border-bottom: 0 none;
	min-height: 30px;
	float: left;
	max-width: 32%;
}

#post-body .misc-pub-section-last {
	border-right: 0;
}

#misc-publishing-actions {
	padding: 6px 0 0;
}

.misc-pub-section {
	padding: 6px 10px 8px;
	border-width: 1px 0;
	border-style: solid;
}

.misc-pub-section:first-child {
	border-top-width: 0;
}
.misc-pub-section-last {
	border-bottom-width: 0;
}

#minor-publishing-actions {
	padding: 10px 10px 2px 8px;
	text-align: right;
}

#minor-publishing {
	border-bottom-width: 1px;
	border-bottom-style: solid;
	-webkit-box-shadow: 0 1px 0 #fff;
	-moz-box-shadow: 0 1px 0 #fff;
	box-shadow: 0 1px 0 #fff;
}

#save-post {
	float: left;
}

#minor-publishing .ajax-loading {
	padding: 3px 0 0 4px;
	float: left;
}

.preview {
	float: right;
}

#sticky-span {
	margin-left: 18px;
}

#post-status-display,
#post-visibility-display {
	font-weight: bold;
}

.side-info {
	margin: 0;
	padding: 4px;
	font-size: 11px;
}

.side-info h5 {
	padding-bottom: 7px;
	font-size: 14px;
	margin: 12px 2px 5px;
	border-bottom-width: 1px;
	border-bottom-style: solid;
}

.side-info ul {
	margin: 0;
	padding-left: 18px;
	list-style: square;
}

a.button,
a.button-primary,
a.button-secondary {
	line-height: 15px;
	padding: 3px 10px;
	white-space: nowrap;
	-webkit-border-radius: 10px;
}

.approve,
.unapproved .unapprove {
	display: none;
}

.unapproved .approve,
.spam .approve,
.trash .approve {
	display: inline;
}

td.action-links,
th.action-links {
	text-align: right;
}

.describe .del-link {
	padding-left: 5px;
}


/*------------------------------------------------------------------------------
  4.0 - Notifications
------------------------------------------------------------------------------*/

#update-nag, .update-nag {
	line-height: 19px;
	padding: 5px 0;
	font-size: 12px;
	text-align: center;
	margin: 0 15px;
	border-width: 1px;
	border-style: solid;
	border-top-width: 0;
	border-top-style: none;
	-webkit-border-bottom-right-radius: 3px;
	-webkit-border-bottom-left-radius: 3px;
	border-bottom-right-radius: 3px;
	border-bottom-left-radius: 3px;
}

.plugins .plugin-update {
	padding: 0;
}

.plugin-update .update-message {
	margin: 0 10px 8px 31px;
	font-weight: bold;
}

ul#dismissed-updates {
	display: none;
}

form.upgrade {
	margin-top: 8px;
}

form.upgrade .hint {
	font-style: italic;
	font-size: 85%;
	margin: -0.5em 0 2em 0;
}

.ajax-feedback {
	visibility: hidden;
	vertical-align: bottom;
}

#ajax-response.alignleft {
	margin-left: 2em;
}


/* Distraction Free Writing mode
 * =Overlay Styles
-------------------------------------------------------------- */
.fullscreen-overlay {
	z-index: 149999;
	display: none;
	position: fixed;
	top: 0;
	bottom: 0;
	left: 0;
	right: 0;
	filter: inherit;
}

.fullscreen-active .fullscreen-overlay,
.fullscreen-active #wp-fullscreen-body {
	display: block;
}

.fullscreen-fader {
	z-index: 200000;
}

.fullscreen-active .fullscreen-fader {
	display: none;
}

/* =Overlay Body
-------------------------------------------------------------- */
#wp-fullscreen-body {
	width: 100%;
	z-index: 150005;
	display: none;
	position: absolute;
	top: 0;
	left: 0;
}

#wp-fullscreen-wrap {
	margin: 0 auto 50px;
	position: relative;
	padding-top: 60px;
}

#wp-fullscreen-title {
    font-size: 1.7em;
    line-height: 100%;
    outline: medium none;
    padding: 6px 7px;
    width: 100%;
    margin-bottom: 30px;
}

#wp-fullscreen-container {
	padding: 4px 10px 50px;
}

#wp-fullscreen-title,
#wp-fullscreen-container {
	-webkit-border-radius: 0;
	border-radius: 0;
	border: 1px dashed transparent;
	background: transparent;
	-moz-transition-property: border-color;
	-moz-transition-duration: 0.6s;
	-webkit-transition-property: border-color;
	-webkit-transition-duration: 0.6s;
	-o-transition-property: border-color;
	-o-transition-duration: 0.6s;
	transition-property: border-color;
	transition-duration: 0.6s;
}

#wp_mce_fullscreen {
	width: 100%;
	min-height: 300px;
	border: 0;
	background: transparent;
	font-family: Consolas, Monaco, monospace;
	line-height: 1.6em;
	padding: 0;
	overflow-y: hidden;
	outline: none;
	resize: none;
}

#wp-fullscreen-tagline {
	color: #BBBBBB;
	font-size: 18px;
	float: right;
	padding-top: 5px;
}

/* =Top bar
-------------------------------------------------------------- */
#fullscreen-topbar {
	position: fixed;
	top: 0;
	left: 0;
	z-index: 150050;
	border-bottom-style: solid;
    border-bottom-width: 1px;
	min-width: 800px;
	width: 100%;
	height: 40px;
}

#wp-fullscreen-toolbar {
	padding: 6px 10px 0;
	clear: both;
	max-width: 1100px;
	min-width: 820px;
	margin: 0 auto;
}

#wp-fullscreen-mode-bar,
#wp-fullscreen-button-bar,
#wp-fullscreen-close,
#wp-fullscreen-count {
	float: left;
}

#wp-fullscreen-save {
	float: right;
	padding: 2px 2px 0 5px;
}

#wp-fullscreen-count,
#wp-fullscreen-close {
	padding-top: 5px;
}

#wp-fullscreen-central-toolbar {
	margin: auto;
	padding: 0;
}

#wp-fullscreen-buttons > div {
	float: left;
}

#wp-fullscreen-mode-bar {
	padding: 1px 14px 0 0;
}

#wp-fullscreen-modes a {
	display: block;
	font-size: 11px;
	text-decoration: none;
	float: left;
	margin: 1px 0 0 0;
	padding: 2px 6px 2px;
	border-width: 1px 1px 1px 0;
	border-style: solid;
	border-color: #bbb;
	color: #777;
	text-shadow: 0 1px 0 #fff;
	background-color: #f4f4f4;
	background-image: -moz-linear-gradient(bottom,  #e4e4e4,  #f9f9f9);
	background-image: -webkit-gradient(linear, left bottom, left top, from(#e4e4e4), to(#f9f9f9));
}

#wp-fullscreen-modes a:hover,
.wp-html-mode #wp-fullscreen-modes a:last-child,
.wp-tmce-mode #wp-fullscreen-modes a:first-child {
	color: #333;
	border-color: #999;
	background-color: #eee;
	background-image: -moz-linear-gradient(bottom,  #f9f9f9,  #e0e0e0);
	background-image: -webkit-gradient(linear, left bottom, left top, from(#f9f9f9), to(#e0e0e0));
}

#wp-fullscreen-modes a:first-child {
	border-width: 1px;
	-webkit-border-top-left-radius: 3px;
	-webkit-border-bottom-left-radius: 3px;
	border-top-left-radius: 3px;
	border-bottom-left-radius: 3px;
}

#wp-fullscreen-modes a:last-child {
	-webkit-border-top-right-radius: 3px;
	-webkit-border-bottom-right-radius: 3px;
	border-top-right-radius: 3px;
	border-bottom-right-radius: 3px;
}

#wp-fullscreen-buttons .active a {
	background: inherit;
}

#wp-fullscreen-buttons .hidden {
	display: none;
}

#wp-fullscreen-buttons .disabled {
	opacity: 0.5;
}

.wp-html-mode #wp-fullscreen-buttons div {
	display: none;
}

.wp-html-mode #wp-fullscreen-buttons div.wp-fullscreen-both {
	display: block;
}

#fullscreen-topbar.fullscreen-make-sticky {
	display: block !important;
}

#wp-fullscreen-save img {
	vertical-align: middle;
}

#wp-fullscreen-save img,
#wp-fullscreen-save span {
	padding-right: 4px;
	display: none;
}

#wp-fullscreen-buttons .mce_image .mce_image {
	background-image: url("../images/menu.png?ver=20100531");
	background-position: -124px -38px;
}

#wp-fullscreen-buttons .mce_image .mce_image:hover {
	background-position: -124px -6px;
}

/* =Thickbox Adjustments
-------------------------------------------------------------- */
.fullscreen-active #TB_overlay {
	z-index: 150100;
}

.fullscreen-active #TB_window {
	z-index: 150102;
}

/* =TinyMCE Adjustments
-------------------------------------------------------------- */
#wp_mce_fullscreen_ifr {
	background: transparent;
}

#wp_mce_fullscreen_parent #wp_mce_fullscreen_tbl tr.mceFirst {
	display : none;
}

#wp-fullscreen-container .wp_themeSkin table td {
	vertical-align: top;
}


/*------------------------------------------------------------------------------
  6.0 - Admin Header
------------------------------------------------------------------------------*/
#wphead {
	height: 32px;
	margin-right: 20px;
	margin-left: 2px;
}

#wphead a,
#adminmenu a,
#sidemenu a,
#taglist a,
#catlist a {
	text-decoration: none;
}

#header-logo {
	float: left;
	margin: 7px 0;
	-webkit-user-select: none;
	-moz-user-select: none;
	user-select: none;
}

#wphead h1 {
	font-style: normal;
	font-size: 16px;
	padding: 6px 8px 5px;
	margin: 0;
	float: left;
}

#wphead h1 a:hover {
	text-decoration:none;
}

#wphead h1 a:hover #site-title {
	text-decoration:underline;
}


/*------------------------------------------------------------------------------
  6.1 - Favorites Menu
------------------------------------------------------------------------------*/

#favorite-actions {
	margin: 0 12px 0 15px;
	min-width: 130px;
	position: relative;
	display: inline-block;
	top: -1px;
}

#favorite-first {
	-webkit-border-radius: 12px;
	border-radius: 12px;
	line-height: 15px;
	padding: 0 30px 0 0;
	border-width: 1px;
	border-style: solid;
}

#favorite-inside {
	margin: 0;
	padding: 2px 1px;
	border-width: 1px;
	border-style: solid;
	position: absolute;
	z-index: 11;
	display: none;
	-webkit-border-bottom-right-radius: 12px;
	-webkit-border-bottom-left-radius: 12px;
	border-bottom-right-radius: 12px;
	border-bottom-left-radius: 12px;
}

#favorite-first a {
	padding: 2px 0 2px 12px;
}

#favorite-actions a {
	display: block;
	text-decoration: none;
	font-size: 11px;
}

#favorite-inside a {
	padding: 3px 5px 3px 10px;
	line-height: 20px;
}

#favorite-toggle {
	height: 18px;
	position: absolute;
	right: 0;
	top: 1px;
	width: 28px;
	border-width: 0 0 0 1px;
	border-style: solid;
}

#favorite-actions .slide-down {
	-webkit-border-bottom-right-radius: 0;
	-webkit-border-bottom-left-radius: 0;
	border-bottom-right-radius: 0;
	border-bottom-left-radius: 0;
	border-bottom: none;
}


/*------------------------------------------------------------------------------
  6.2 - Screen Options Tabs
------------------------------------------------------------------------------*/

#screen-meta {
	position: fixed;
	top: -250px;
	left: 146px;
	right: 0;
	z-index: 20;
	margin: 28px 15px 0 20px;
	padding: 0;
}

.folded #screen-meta {
	left: 33px;
}

#screen-options-wrap,
#contextual-help-wrap {
	margin: 0;
	padding: 8px 20px 12px;
	max-height: 300px;
	overflow: auto;
}

#screen-meta .screen-reader-text {
	visibility: hidden;
}

.toggle-arrow {
	background-repeat: no-repeat;
	background-position: top left;
	background-color: transparent;
	height: 22px;
	line-height: 22px;
	display: block;
}
.toggle-arrow-active {
	background-position: bottom left;
}

#screen-options-wrap h5,
#contextual-help-wrap h5 {
	margin: 8px 0;
	font-size: 13px;
}

.metabox-prefs label {
	display: inline-block;
	padding-right: 15px;
	white-space: nowrap;
	line-height: 30px;
}

.metabox-prefs label input {
	margin: 0 5px 0 2px;
}

.metabox-prefs label a {
	display: none;
}

/*------------------------------------------------------------------------------
  6.3 - Help Menu
------------------------------------------------------------------------------*/

#contextual-help-back {
	position: absolute;
	top: 0;
	left: 3px;
	right: -1px;
	bottom: -1px;

	border-width: 0 1px 1px;
	border-style: solid;

	-webkit-border-bottom-right-radius: 3px;
	-webkit-border-bottom-left-radius: 3px;
	border-bottom-right-radius: 3px;
	border-bottom-left-radius: 3px;
}

#contextual-help-wrap {
	position: relative;
	padding: 0 0 0 4px;
	overflow: auto;
}

.contextual-help-tabs {
	float: left;
	width: 150px;
	margin: 0;
}

.contextual-help-tabs ul {
	margin: 1em 0;
}

.contextual-help-tabs li {
	margin-bottom: 0;
	list-style-type: none;
	border-style: solid;
	border-width: 1px 0;
	border-color: transparent;
}

.contextual-help-tabs a {
	display: block;
	padding: 5px 5px 5px 12px;
	line-height: 18px;
	text-decoration: none;
}

.contextual-help-tabs .active {
	padding: 0 2px;
	margin: 0 -1px 0 -3px;
	border-width: 1px 0 1px 1px;
	border-style: solid;
}

.contextual-help-tabs-wrap {
	padding: 0 20px;
	overflow: auto;

	border-width: 0 1px;
	border-style: solid;
}

.help-tab-content {
	display: none;
	margin: 0 22px 12px 0;
	line-height: 1.6em;
}

.help-tab-content.active {
	display: block;
}

.help-tab-content li {
	list-style-type: disc;
	margin-left: 18px;
}

.contextual-help-sidebar {
	width: 150px;
	float: right;
	padding: 0 8px 0 12px;
	overflow: auto;
}


/*------------------------------------------------------------------------------
  7.0 - Main Navigation (Left Menu)
------------------------------------------------------------------------------*/

#adminmenuback,
#adminmenuwrap {
	border-width: 0 1px 0 0;
	border-style: solid;
}
#adminmenuwrap {
	position: relative;
}

#adminmenushadow {
	position: absolute;
	top: 0;
	right: 0;
	bottom: 0;
	width: 6px;
	z-index: 20;
}

/* side admin menu */
#adminmenu * {
	-webkit-user-select: none;
	-moz-user-select: none;
	user-select: none;
}

#adminmenu .wp-submenu {
	list-style: none;
	padding: 0;
	margin: 0;
	overflow: hidden;
}

#adminmenu li .wp-submenu,
.folded #adminmenu .wp-has-current-submenu .wp-submenu {
	display: none;
	position: absolute;
	top: -1px;
	left: 146px;
	z-index: 999;
	overflow: hidden;
}

.js #adminmenu .wp-submenu.sub-open,
.folded #adminmenu .wp-has-current-submenu .wp-submenu.sub-open,
.no-js #adminmenu .wp-has-submenu:hover .wp-submenu {
	display: block;
}

#adminmenu .wp-has-current-submenu .wp-submenu {
	position: relative;
	display: block;
	z-index: 2;
	top: auto;
	left: auto;
	right: auto;
	bottom: auto;
	padding: 0;
}

#adminmenu .wp-has-current-submenu .wp-submenu-wrap {
	-moz-box-shadow: none;
	-webkit-box-shadow: none;
	box-shadow: none;
}

.folded #adminmenu .wp-submenu,
.folded #adminmenu .wp-has-current-submenu .wp-submenu {
	top: -5px;
	left: 26px;
}

#adminmenu .wp-submenu.sub-open,
.folded #adminmenu .wp-has-current-submenu .wp-submenu.sub-open,
.no-js #adminmenu .wp-has-submenu:hover .wp-submenu,
.no-js.folded #adminmenu .wp-has-current-submenu:hover .wp-submenu {
	padding: 0 8px 8px 0;
}

.no-js #adminmenu .wp-has-current-submenu:hover .wp-submenu,
#adminmenu .wp-has-current-submenu .wp-submenu {
	padding: 0;
}

#adminmenu .wp-submenu a {
	font-size: 12px;
	line-height: 18px;
}

#adminmenu .wp-submenu li.current,
#adminmenu .wp-submenu li.current a,
#adminmenu .wp-submenu li.current a:hover {
	font-weight: bold;
}

#adminmenu a.menu-top,
#adminmenu .wp-submenu-head {
	font-size: 13px;
	line-height: 18px;
}

#adminmenu div.wp-submenu-head {
	display: none;
}

.folded #adminmenu div.wp-submenu-head {
	display: block;
}

.folded #adminmenu a.menu-top,
body.no-js #adminmenu .wp-menu-toggle,
.folded #adminmenu div.wp-menu-toggle {
	display: none;
}

#adminmenu div.wp-menu-image {
	float: left;
	width: 28px;
	height: 28px;
}
.folded #adminmenu div.wp-menu-image {
	width: 32px;
}

#adminmenu li {
	margin: 0;
	padding: 0;
	cursor: pointer;
}

#adminmenu a {
	display: block;
	line-height: 18px;
	padding: 2px 5px;
}

#adminmenu li.menu-top {
	min-height: 29px;
	position: relative;
}

#adminmenu a.menu-top {
	font-weight: bold;
	line-height: 18px;
	min-width: 10em;
	padding: 5px 5px;
	border-width: 1px 0 1px;
	border-style: solid;
}

#adminmenu li.wp-menu-open {
	border-width: 0 0 1px;
	border-style: solid;
}

#adminmenu .wp-submenu a {
	margin: 0;
	padding-left: 12px;
}

#adminmenu li li {
	margin-left: 8px;
}

.js.folded #adminmenu li li {
	margin-left: 0;
}

#adminmenu li li a {
	padding-left: 12px;
}

.folded #adminmenu li li a {
	padding-left: 0;
}

.wp-menu-arrow {
	display: none;
}

#adminmenu li.wp-has-current-submenu .wp-menu-arrow,
#adminmenu li.menu-top.current .wp-menu-arrow,
#adminmenu li.wp-has-submenu:hover .wp-menu-arrow {
	display: block;
	position: absolute;
	right: -9px;
	top: 0;
	cursor: auto;
	z-index: 25;
}

#adminmenu li.menu-top:hover .wp-menu-arrow {
	z-index: 1001;
}

.folded #adminmenu li.menu-top:hover .wp-menu-arrow {
	display: none;
}

.folded #adminmenu li.menu-top.wp-menu-open:hover .wp-menu-arrow {
	display: block;
	z-index: 125;
}

#adminmenu .wp-menu-arrow div {
	width: 15px;
	height: 30px;
	background: url(../images/menu-arrow-frame.png) top right no-repeat;
}

#adminmenu .wp-submenu li {
	padding: 0;
	margin: 0;
}

.folded #adminmenu li.menu-top {
	border-width: 1px 0;
	border-style: solid none;
}

#adminmenu .wp-menu-image img {
	float: left;
	padding: 8px 6px 0;
	opacity: 0.6;
	filter: alpha(opacity=60);
}

#adminmenu li.menu-top:hover .wp-menu-image img,
#adminmenu li.wp-has-current-submenu .wp-menu-image img {
	opacity: 1;
	filter: alpha(opacity=100);
}

#adminmenu li.wp-menu-separator {
	height: 3px;
	padding: 0;
	margin: 0;
	border-width: 1px 0;
	border-style: solid;
	cursor: inherit;
}

#adminmenu div.separator {
	height: 1px;
	padding: 0;
	border-width: 1px 0 0 0;
	border-style: solid;
}

#adminmenu .wp-submenu .wp-submenu-head {
	padding: 6px 4px 5px 10px;
	cursor: default;
	border-width: 1px 0;
	border-style: solid;
}

#adminmenu li .wp-submenu-wrap {
	border-width: 1px 1px 1px 0;
	border-style: solid solid solid none;
	position: relative;
	-webkit-border-bottom-right-radius: 3px;
	-webkit-border-top-right-radius: 3px;
	border-bottom-right-radius: 3px;
	border-top-right-radius: 3px;
}

#adminmenu li.wp-menu-open .wp-submenu-wrap {
	border: 0 none;
}

.folded #adminmenu .wp-submenu .wp-submenu-wrap {
	margin-top: 4px;
}

.folded #adminmenu .wp-submenu ul {
	border-width: 0 0 0 1px;
	border-style: solid;
}

.folded #adminmenu .wp-submenu a {
	padding-left: 10px;
}

.folded #adminmenu a.wp-has-submenu {
	margin-left: 40px;
}

#adminmenu .wp-menu-toggle {
	width: 18px;
	clear: right;
	float: right;
	margin: 1px 0 0;
	height: 27px;
	padding: 1px 2px 0 0;
	cursor: pointer;
}

#adminmenu .wp-menu-image a {
	height: 24px;
}

#adminmenu .wp-menu-image img {
	padding: 6px 0 0 1px;
}

#adminmenu .awaiting-mod,
#adminmenu span.update-plugins,
#sidemenu li a span.update-plugins {
	position: absolute;
	font-family: sans-serif;
	font-size: 9px;
	line-height: 17px;
	font-weight: bold;
	margin-top: 1px;
	margin-left: 7px;
	-webkit-border-radius: 10px;
	border-radius: 10px;
}

#adminmenu li .awaiting-mod span,
#adminmenu li span.update-plugins span,
#sidemenu li a span.update-plugins span {
	display: block;
	padding: 0 6px;
}

#adminmenu li span.count-0,
#sidemenu li a .count-0 {
	display: none;
}

.post-com-count-wrapper {
	min-width: 22px;
	font-family: sans-serif;
}

.post-com-count {
	height: 1.3em;
	line-height: 1.1em;
	display: block;
	text-decoration: none;
	padding: 0 0 6px;
	cursor: pointer;
	background-position: center -80px;
	background-repeat: no-repeat;
}

.post-com-count span {
	font-size: 11px;
	font-weight: bold;
	height: 1.4em;
	line-height: 1.4em;
	min-width: 0.7em;
	padding: 0 6px;
	display: inline-block;
	-webkit-border-radius: 5px;
	border-radius: 5px;
}

strong .post-com-count {
	background-position: center -55px;
}

.post-com-count:hover {
	background-position: center -3px;
}

.column-response .post-com-count {
	float: left;
	margin-right: 5px;
	text-align: center;
}

.response-links {
	float: left;
}

#the-comment-list .attachment-80x60 {
	padding: 4px 8px;
}

#collapse-menu {
	font-size: 12px;
	line-height: 34px;
}

.folded #collapse-menu span {
	display: none;
}

#collapse-button,
#collapse-button div {
	width: 15px;
	height: 15px;
}

#collapse-button {
	float: left;
	margin: 8px 6px;
	border-width: 1px;
	border-style: solid;
	-webkit-border-radius: 10px;
	border-radius: 10px;
}


/*------------------------------------------------------------------------------
  8.0 - Layout Blocks
------------------------------------------------------------------------------*/

body.admin-bar #wpcontent,
body.admin-bar #adminmenu {
	padding-top: 28px;
}

.narrow {
	width: 70%;
	margin-bottom: 40px;
}

.narrow p {
	line-height: 150%;
}

.widefat th,
.widefat td {
	overflow: hidden;
}

.widefat th {
	font-weight: normal;
}

.widefat td p {
	margin: 2px 0 0.8em;
}

.widefat .column-comment p {
	margin: 0.6em 0;
}

.postbox-container {
	float: left;
}

.postbox-container .meta-box-sortables {
	min-height: 350px;
}

.postbox-container .meta-box-sortables.empty-container,
#side-sortables.empty-container {
	border: 3px dashed #CCCCCC;
	height: 350px;
}

.postbox .hndle {
	cursor: move;
	-webkit-border-top-left-radius: 3px;
	-webkit-border-top-right-radius: 3px;
	border-top-left-radius: 3px;
	border-top-right-radius: 3px;
}

.postbox.closed .hndle {
	-webkit-border-radius: 3px;
	border-radius: 3px;
}

.hndle a {
	font-size: 11px;
	font-weight: normal;
}

.postbox .handlediv {
	float: right;
	width: 27px;
	height: 30px;
	cursor: pointer;
}

.sortable-placeholder {
	border-width: 1px;
	border-style: dashed;
	margin-bottom: 20px;
}

.widget,
.postbox,
.stuffbox {
	margin-bottom: 20px;
	padding: 0;
	border-width: 1px;
	border-style: solid;
	line-height: 1;
}

.widget .widget-top,
.postbox h3,
.stuffbox h3 {
	margin-top: 1px;
	border-bottom-width: 1px;
	border-bottom-style: solid;
	cursor: move;
	-webkit-user-select: none;
	-moz-user-select: none;
	user-select: none;
}

.postbox .inside,
.stuffbox .inside {
	padding: 0 10px;
	line-height: 1.4em;
}

.postbox.closed h3 {
	border: none;
	-moz-box-shadow: none;
	-webkit-box-shadow: none;
	box-shadow: none;
}

.postbox table.form-table {
	margin-bottom: 0;
}

.temp-border {
	border: 1px dotted #ccc;
}

.columns-prefs label {
	padding: 0 5px;
}


/*------------------------------------------------------------------------------
  9.0 - Dashboard
------------------------------------------------------------------------------*/

#wpbody-content .metabox-holder {
	padding-top: 10px;
}

#dashboard-widgets .meta-box-sortables {
	margin: 0 8px;
}

#dashboard_recent_comments div.undo {
	border-top-style: solid;
	border-top-width: 1px;
	margin: 0 -10px;
	padding: 3px 8px;
	font-size: 11px;
}

#the-comment-list td.comment p.comment-author {
	margin-top: 0;
	margin-left: 0;
}

#the-comment-list p.comment-author img {
	float: left;
	margin-right: 8px;
}

#the-comment-list p.comment-author strong a {
	border: none;
}

#the-comment-list td {
	vertical-align: top;
}

#the-comment-list td.comment {
	word-wrap: break-word;
}

.welcome-panel {
	margin: 20px 8px;
	padding: 0 10px;
	border-width: 3px;
	border-style: double;
	position: relative;
	display: none;
}

.welcome-panel h3 {
	font-size: 24px;
	font-weight: normal;
}

.welcome-panel .welcome-panel-close {
	position: absolute;
	top: 10px;
	right: 10px;
	text-decoration: none;
}


/*------------------------------------------------------------------------------
  10.0 - List Posts (/Pages/etc)
------------------------------------------------------------------------------*/

table.fixed {
	table-layout: fixed;
}

.fixed .column-rating,
.fixed .column-visible {
	width: 8%;
}

.fixed .column-date,
.fixed .column-parent,
.fixed .column-links {
	width: 10%;
}

.fixed .column-response,
.fixed .column-author,
.fixed .column-categories,
.fixed .column-tags,
.fixed .column-rel,
.fixed .column-role {
	width: 15%;
}

.fixed .column-comments {
	width: 4em;
	padding: 8px 0;
	text-align: left;
}

.fixed .column-comments .vers {
	padding-left: 3px;
}

.fixed .column-comments a {
	float: left;
}

.fixed .column-slug {
	width: 25%;
}

.fixed .column-posts {
	width: 10%;
}

.fixed .column-icon {
	width: 80px;
}

#commentsdiv .fixed .column-author,
#comments-form .fixed .column-author {
	width: 20%;
}

#commentsdiv.postbox .inside {
	margin: 0;
	padding: 0;
}

#commentsdiv.postbox .inside .row-actions {
	line-height:18px;
}

#commentsdiv.postbox .inside td {
	padding:1em 10px;
}

#commentsdiv.postbox .inside .column-author {
	width:33%;
}

#commentsdiv.postbox .inside p {
	margin:6px 10px 8px;
}

#commentsdiv.postbox .column-comment p {
	margin:0.6em 0;
}

#commentsdiv.postbox #replyrow td {
	padding:0;
}

.sorting-indicator {
	display: none;
	width: 7px;
	height: 4px;
	margin-top: 8px;
	margin-left: 7px;
	position: absolute;
	background-image: url(../images/sort.gif);
	background-repeat: no-repeat;
}

.fixed .column-comments .sorting-indicator {
	margin-top: 3px;
}

.widefat th.sortable,
.widefat th.sorted {
	padding: 0;
}

th.sortable a,
th.sorted a {
	display: block;
	overflow: hidden;
	position: relative;
	padding: 7px 7px 8px;
}

.fixed .column-comments.sortable a,
.fixed .column-comments.sorted a {
	padding: 8px 0;
}

th.sortable a span,
th.sorted a span {
	float: left;
	cursor: pointer;
}

th.sorted.asc .sorting-indicator,
th.desc:hover span.sorting-indicator {
	display: inline;
	background-position: 0 0;
}

th.sorted.desc .sorting-indicator,
th.asc:hover span.sorting-indicator {
	display: inline;
	background-position: -7px 0;
}

/* Bulk Actions */
.tablenav-pages a {
	border-bottom-style: solid;
	border-bottom-width: 2px;
	font-weight: bold;
	margin-right: 1px;
	padding: 0 2px;
}
.tablenav-pages .current-page {
	text-align: center;
}
.tablenav-pages .next-page {
	margin-left: 2px;
}

.tablenav a.button-secondary {
	display: block;
	margin: 3px 8px 0 0;
}

.tablenav {
	clear: both;
	height: 30px;
	margin: 6px 0 4px;
	vertical-align: middle;
}

.tablenav.themes {
	max-width: 98%;
}

.tablenav .tablenav-pages {
	float: right;
	display: block;
	cursor: default;
	height: 30px;
	line-height: 30px;
	font-size: 12px;
}

.tablenav .no-pages,
.tablenav .one-page .pagination-links {
	display: none;
}

.tablenav .tablenav-pages a,
.tablenav-pages span.current  {
	text-decoration: none;
	padding: 3px 6px;
}

.tablenav .tablenav-pages a.disabled:hover {
	cursor: default;
}

.tablenav .tablenav-pages a.disabled:active {
	cursor: default;
}

.tablenav .displaying-num {
	margin-right: 10px;
	font-size: 12px;
	font-style: italic;
}

.tablenav .actions {
	padding: 2px 8px 0 0;
}

.tablenav .delete {
	margin-right: 20px;
}

.view-switch {
	float: right;
	margin: 6px 8px 0;
}

.view-switch a {
	text-decoration: none;
}

.filter {
	float: left;
	margin: -5px 0 0 10px;
}

.filter .subsubsub {
	margin-left: -10px;
	margin-top: 13px;
}
.screen-per-page {
	width: 3em;
}

#posts-filter fieldset {
	float: left;
	margin: 0 1.5ex 1em 0;
	padding: 0;
}

#posts-filter fieldset legend {
	padding: 0 0 .2em 1px;
}

span.post-state-format {
	font-weight: normal;
}


/*------------------------------------------------------------------------------
  10.1 - Inline Editing
------------------------------------------------------------------------------*/

/*
.quick-edit* is for Quick Edit
.bulk-edit* is for Bulk Edit
.inline-edit* is for everything
*/

/*	Layout */
tr.inline-edit-row td {
	padding: 0 0.5em;
}

#wpbody-content .inline-edit-row fieldset {
	font-size: 12px;
	float: left;
	margin: 0;
	padding: 0;
	width: 100%;
}

#wpbody-content .inline-edit-row fieldset .inline-edit-col {
	padding: 0 0.5em;
}

#wpbody-content .quick-edit-row-page fieldset.inline-edit-col-right .inline-edit-col {
	border-width: 0 0 0 1px;
	border-style: none none none solid;
}

#wpbody-content .quick-edit-row-post .inline-edit-col-left {
	width: 40%;
}

#wpbody-content .quick-edit-row-post .inline-edit-col-right {
	width: 39%;
}

#wpbody-content .inline-edit-row-post .inline-edit-col-center {
	width: 20%;
}

#wpbody-content .quick-edit-row-page .inline-edit-col-left {
	width: 50%;
}

#wpbody-content .quick-edit-row-page .inline-edit-col-right,
#wpbody-content .bulk-edit-row-post .inline-edit-col-right {
	width: 49%;
}

#wpbody-content .bulk-edit-row .inline-edit-col-left {
	width: 30%;
}

#wpbody-content .bulk-edit-row-page .inline-edit-col-right {
	width: 69%;
}

#wpbody-content .bulk-edit-row .inline-edit-col-bottom {
	float: right;
	width: 69%;
}

#wpbody-content .inline-edit-row-page .inline-edit-col-right {
	margin-top: 27px;
}

.inline-edit-row fieldset .inline-edit-group {
	clear: both;
}

.inline-edit-row fieldset .inline-edit-group:after {
	content: ".";
	display: block;
	height: 0;
	clear: both;
	visibility: hidden;
}

.inline-edit-row p.submit {
	clear: both;
	padding: 0.5em;
	margin: 0.5em 0 0;
}

.inline-edit-row span.error {
	line-height: 22px;
	margin: 0 15px;
	padding: 3px 5px;
}

/*	Positioning */
.inline-edit-row h4 {
	margin: .2em 0;
	padding: 0;
	line-height: 23px;
}
.inline-edit-row fieldset span.title,
.inline-edit-row fieldset span.checkbox-title {
	margin: 0;
	padding: 0;
	line-height: 27px;
}

.inline-edit-row fieldset label,
.inline-edit-row fieldset span.inline-edit-categories-label {
	display: block;
	margin: .2em 0;
}

.inline-edit-row fieldset label.inline-edit-tags {
	margin-top: 0;
}

.inline-edit-row fieldset label.inline-edit-tags span.title {
	margin: .2em 0;
}

.inline-edit-row fieldset label span.title {
	display: block;
	float: left;
	width: 5em;
}

.inline-edit-row fieldset label span.input-text-wrap {
	display: block;
	margin-left: 5em;
}

.quick-edit-row-post fieldset.inline-edit-col-right label span.title {
	width: auto;
	padding-right: 0.5em;
}

.inline-edit-row .input-text-wrap input[type=text] {
	width: 100%;
}

.inline-edit-row fieldset label input[type=checkbox] {
	vertical-align: text-bottom;
}

.inline-edit-row fieldset label textarea {
	width: 100%;
	height: 4em;
}

#wpbody-content .bulk-edit-row fieldset .inline-edit-group label {
	max-width: 50%;
}

#wpbody-content .quick-edit-row fieldset .inline-edit-group label.alignleft:first-child {
	margin-right: 0.5em
}

.inline-edit-col-right .input-text-wrap input.inline-edit-menu-order-input {
	width: 6em;
}

/*	Styling */
.inline-edit-row h4 {
	text-transform: uppercase;
}

.inline-edit-row fieldset span.title,
.inline-edit-row fieldset span.checkbox-title {
	font-style: italic;
	line-height: 1.8em;
}

/*	Specific Elements */
.inline-edit-row fieldset input[type="text"],
.inline-edit-row fieldset textarea {
	border-style: solid;
	border-width: 1px;
}

.inline-edit-row fieldset .inline-edit-date {
	float: left;
}

.inline-edit-row fieldset input[name=jj],
.inline-edit-row fieldset input[name=hh],
.inline-edit-row fieldset input[name=mn] {
	font-size: 12px;
	width: 2.1em;
}

.inline-edit-row fieldset input[name=aa] {
	font-size: 12px;
	width: 3.5em;
}

.inline-edit-row fieldset label input.inline-edit-password-input {
	width: 8em;
}

.inline-edit-row .catshow,
.inline-edit-row .cathide {
	cursor: pointer;
}

ul.cat-checklist {
	height: 12em;
	border-style: solid;
	border-width: 1px;
	overflow-y: scroll;
	padding: 0 5px;
	margin: 0;
}

#bulk-titles {
	display: block;
	height: 12em;
	border-style: solid;
	border-width: 1px;
	overflow-y: scroll;
	padding: 0 5px;
	margin: 0 0 5px;
}

.inline-edit-row fieldset ul.cat-checklist li,
.inline-edit-row fieldset ul.cat-checklist input {
	margin: 0;
}

.inline-edit-row fieldset ul.cat-checklist label,
.inline-edit-row .catshow,
.inline-edit-row .cathide,
.inline-edit-row #bulk-titles div {
	font-family: sans-serif;
	font-style: normal;
	font-size: 11px;
}

table .inline-edit-row fieldset ul.cat-hover {
	height: auto;
	max-height: 30em;
	overflow-y: auto;
	position: absolute;
}

.inline-edit-row fieldset label input.inline-edit-menu-order-input {
	width: 3em;
}

.inline-edit-row fieldset label input.inline-edit-slug-input {
	width: 75%;
}

.quick-edit-row-post fieldset label.inline-edit-status {
	float: left;
}

#bulk-titles {
	line-height: 140%;
}
#bulk-titles div {
	margin: 0.2em 0.3em;
}

#bulk-titles div a {
	cursor: pointer;
	display: block;
	float: left;
	height: 10px;
	margin: 3px 3px 0 -2px;
	overflow: hidden;
	position: relative;
	text-indent: -9999px;
	width: 10px;
}


/*------------------------------------------------------------------------------
  11.0 - Write/Edit Post Screen
------------------------------------------------------------------------------*/

#titlediv {
	position: relative;
	margin-bottom: 20px;
}
#titlediv label { cursor: text; }

#titlediv div.inside {
	margin: 0;
}

#poststuff #titlewrap {
	border: 0;
	padding: 0;

}

#titlediv #title {
	padding: 3px 4px;
	font-size: 1.7em;
	line-height: 100%;
	width: 100%;
	outline: none;
}

#titlediv #title-prompt-text,
#wp-fullscreen-title-prompt-text {
	color: #bbb;
	position: absolute;
	font-size: 1.7em;
	padding: 8px;
}

#wp-fullscreen-title-prompt-text {
	left: 0;
	padding: 11px;
}

#poststuff .inside-submitbox,
#side-sortables .inside-submitbox {
	margin: 0 3px;
	font-size: 11px;
}

input#link_description,
input#link_url {
	width: 98%;
}

#pending {
	background: 0 none;
	border: 0 none;
	padding: 0;
	font-size: 11px;
	margin-top: -1px;
}

#edit-slug-box {
	height: 1em;
	margin-top: 8px;
	padding: 0 7px;
}

#editable-post-name-full {
	display: none;
}

#editable-post-name input {
	width: 16em;
}

.postarea h3 label {
	float: left;
}

#submitpost #ajax-loading,
#submitpost .ajax-loading {
	vertical-align: middle;
}

#wpcontent .ajax-loading {
	visibility: hidden;
}

.submitbox .submit {
	text-align: left;
	padding: 12px 10px 10px;
	font-size: 11px;
}

.submitbox .submitdelete {
	border-bottom-width: 1px;
	border-bottom-style: solid;
	text-decoration: none;
	padding: 1px 2px;
}

.inside-submitbox #post_status {
	margin: 2px 0 2px -2px;
}

.submitbox .submit a:hover {
	border-bottom-width: 1px;
	border-bottom-style: solid;
}

.submitbox .submit input {
	margin-bottom: 8px;
	margin-right: 4px;
	padding: 6px;
}

#post-status-select, #post-format {
	line-height: 2.5em;
	margin-top: 3px;
}

/* Post Screen */
#post-body #normal-sortables {
	min-height: 50px;
}

#post-body #advanced-sortables {
	min-height: 20px;
}

.postbox {
	position: relative;
	min-width: 255px;
}

#trackback_url {
	width: 99%;
}

#normal-sortables .postbox .submit {
	background: transparent none;
	border: 0 none;
	float: right;
	padding: 0 12px;
	margin:0;
}

#side-sortables .category-add input[type="text"],
#side-sortables .category-add select {
	width: 160px;
}

#post-body ul.category-tabs,
#post-body ul.add-menu-item-tabs {
	float: left;
	width: 120px;
	text-align: right;
	/* Negative margin for the sake of those without JS: all tabs display */
	margin: 0 -120px 0 5px;
	padding: 0;
}

#post-body ul.category-tabs li,
#post-body ul.add-menu-item-tabs li {
	padding: 8px;
}

#post-body ul.category-tabs li.tabs,
#post-body ul.add-menu-item-tabs li.tabs {
	-webkit-border-top-left-radius: 3px;
	-webkit-border-bottom-left-radius: 3px;
	border-top-left-radius: 3px;
	border-bottom-left-radius: 3px;
}

#post-body ul.category-tabs li.tabs a,
#post-body ul.add-menu-item-tabs li.tabs a {
	font-weight: bold;
	text-decoration: none;
}

.wp-tab-panel,
.categorydiv div.tabs-panel,
.customlinkdiv div.tabs-panel,
.posttypediv div.tabs-panel,
.taxonomydiv div.tabs-panel,
#linkcategorydiv div.tabs-panel {
	height: 200px;
	overflow: auto;
	padding: 0.5em 0.9em;
	border-style: solid;
	border-width: 1px;
}

.nav-menus-php .customlinkdiv div.tabs-panel,
.nav-menus-php .posttypediv div.tabs-panel,
.nav-menus-php .taxonomydiv div.tabs-panel {
	height: auto;
	max-height: 205px;
}

div.tabs-panel-active {
	display:block;
}

div.tabs-panel-inactive {
	display:none;
}

#post-body .categorydiv div.tabs-panel,
.taxonomy div.tabs-panel,
#post-body #linkcategorydiv div.tabs-panel {
	margin: 0 5px 0 125px;
}

#side-sortables .category-tabs li,
#side-sortables .add-menu-item-tabs li,
.wp-tab-bar li {
	display: inline;
	line-height: 1.35em;
}

#side-sortables .category-tabs li.hide-if-no-js {
 	display: none;
}

#side-sortables .category-tabs a,
#side-sortables .add-menu-item-tabs a,
.wp-tab-bar a {
	text-decoration: none;
}

#side-sortables .category-tabs {
	margin: 8px 0 3px;
}

#category-adder h4 {
	margin: 10px 0;
}

#side-sortables .add-menu-item-tabs,
.wp-tab-bar {
	margin-bottom: 3px;
}

.categorydiv ul,
.customlinkdiv ul,
.posttypediv ul,
.taxonomydiv ul,
#linkcategorydiv ul {
	list-style: none;
	padding: 0;
	margin: 0;
}

#normal-sortables .postbox #replyrow .submit {
	float: none;
	margin: 0;
	padding: 3px 7px;
}

#side-sortables .submitbox .submit input,
#side-sortables .submitbox .submit .preview,
#side-sortables .submitbox .submit a.preview:hover {
	border: 0 none;
}

#side-sortables .inside-submitbox .insidebox,
.stuffbox .insidebox {
	margin: 11px 0;
}

#side-sortables .comments-box,
#normal-sortables .comments-box {
	border: 0 none;
}

ul.category-tabs,
ul.add-menu-item-tabs,
ul.wp-tab-bar {
	margin-top: 12px;
}

#side-sortables .comments-box thead th,
#normal-sortables .comments-box thead th {
	background: transparent;
	padding: 0 7px 4px;
	font-style: italic;
}

ul.category-tabs li.tabs,
ul.add-menu-item-tabs li.tabs,
.wp-tab-active {
	border-style: solid solid none;
	border-width: 1px 1px 0;
}

#commentsdiv img.waiting {
	padding-left: 5px;
}

#post-body .category-tabs li.tabs,
#post-body .add-menu-item-tabs li.tabs {
	border-style: solid none solid solid;
	border-width: 1px 0 1px 1px;
	margin-right: -1px;
}

ul.category-tabs li,
ul.add-menu-item-tabs li,
ul.wp-tab-bar li {
	padding: 3px 5px 5px;
	-webkit-border-top-left-radius: 3px;
	-webkit-border-top-right-radius: 3px;
	border-top-left-radius: 3px;
	border-top-right-radius: 3px;
}

/* positioning etc. */
form#tags-filter {
	position: relative;
}

.screen-per-page {
	width: 3em;
}

#posts-filter fieldset {
	float: left;
	margin: 0 1.5ex 1em 0;
	padding: 0;
}

#posts-filter fieldset legend {
	padding: 0 0 .2em 1px;
}

/* Edit posts */
td.post-title strong, td.plugin-title strong {
	display: block;
	margin-bottom: .2em;
}

td.post-title p, td.plugin-title p {
	margin: 6px 0;
}

/* Global classes */
.wp-hidden-children .wp-hidden-child,
.ui-tabs-hide {
	display: none;
}

.commentlist .avatar {
	vertical-align: text-top;
}

#post-body .tagsdiv #newtag {
	margin-right: 5px;
	width: 16em;
}

#side-sortables input#post_password {
	width: 94%
}

#side-sortables .tagsdiv #newtag {
	width: 68%;
}

#post-status-info {
	border-width: 0 1px 1px;
	border-style: none solid solid;
	width: 100%;
	-webkit-border-bottom-left-radius: 3px;
	-webkit-border-bottom-right-radius: 3px;
	border-bottom-left-radius: 3px;
	border-bottom-right-radius: 3px;
}

#post-status-info td {
	font-size: 12px;
}

.autosave-info {
	padding: 2px 15px 2px 2px;
	text-align: right;
}

#editorcontent #post-status-info {
	border: none;
}

#post-body .wp_themeSkin .mceStatusbar a.mceResize {
	display: block;
	background: transparent url(../images/resize.gif) no-repeat scroll right bottom;
	width: 12px;
	cursor: se-resize;
	margin: 0 2px;
	position: relative;
	top: 22px;
}

#wp-word-count {
	display: block;
	padding: 2px 7px;
}

#timestampdiv select {
	height: 20px;
	line-height: 14px;
	padding: 0;
	vertical-align: top;
}

#jj, #hh, #mn {
	width: 2em;
	padding: 1px;
	font-size: 12px;
}

#aa {
	width: 3.4em;
	padding: 1px;
	font-size: 12px;
}

.curtime #timestamp {
	background-repeat: no-repeat;
	background-position: left top;
	padding-left: 18px;
}

#timestampdiv {
	padding-top: 5px;
	line-height: 23px;
}

#timestampdiv p {
	margin: 8px 0 6px;
}

#timestampdiv input {
	border-width: 1px;
	border-style: solid;
}


/*------------------------------------------------------------------------------
  11.1 - Custom Fields
------------------------------------------------------------------------------*/

#postcustomstuff .updatemeta,
#postcustomstuff .deletemeta {
	margin: auto;
}

#postcustomstuff thead th {
	padding: 5px 8px 8px;
}

#postcustom #postcustomstuff .submit {
	border: 0 none;
	float: none;
	padding: 5px 8px;
}

#side-sortables #postcustom #postcustomstuff .submit {
	padding: 0 5px;
}

#side-sortables #postcustom #postcustomstuff td.left input {
	margin: 3px 3px 0;
}

#side-sortables #postcustom #postcustomstuff #the-list textarea {
	height: 85px;
	margin: 3px;
}

#postcustomstuff table {
	margin: 0;
	width: 100%;
	border-width: 1px;
	border-style: solid;
	border-spacing: 0;
}

#postcustomstuff table input,
#postcustomstuff table select,
#postcustomstuff table textarea {
	width: 95%;
	margin: 8px 0 8px 8px;
}

#postcustomstuff th.left,
#postcustomstuff td.left {
	width: 38%;
}

#postcustomstuff .submit input {
	width: auto;
}

#postcustomstuff #newmeta .submit {
	padding: 0 8px;
}

#postcustomstuff table #addmetasub {
	width: auto;
}

#postcustomstuff #newmetaleft {
	vertical-align: top;
}

#postcustomstuff #newmetaleft a {
	padding: 0 10px;
	text-decoration: none;
}


/*------------------------------------------------------------------------------
  11.2 - Post Revisions
------------------------------------------------------------------------------*/

table.diff {
	width: 100%;
}

table.diff col.content {
	width: 50%;
}

table.diff tr {
	background-color: transparent;
}

table.diff td, table.diff th {
	padding: .5em;
	font-family: Consolas, Monaco, monospace;
	border: none;
}

table.diff .diff-deletedline del, table.diff .diff-addedline ins {
	text-decoration: none;
}


/*------------------------------------------------------------------------------
  12.0 - Categories
------------------------------------------------------------------------------*/

.category-adder {
	margin-left: 120px;
	padding: 4px 0;
}

.category-adder h4 {
	margin: 0 0 8px;
}

#side-sortables .category-adder {
	margin: 0;
}

#normal-sortables .category-add input[type="text"],
#normal-sortables .category-add select {
	width: 30%;
}

#post-body ul.category-tabs,
#post-body ul.add-menu-item-tabs {
	float: left;
	width: 120px;
	text-align: right;
	/* Negative margin for the sake of those without JS: all tabs display */
	margin: 0 -120px 0 5px;
	padding: 0;
}

#post-body ul.category-tabs li,
#post-body ul.add-menu-item-tabs li {
	padding: 8px;
}

#post-body ul.category-tabs li.tabs,
#post-body ul.add-menu-item-tabs li.tabs {
	-webkit-border-top-left-radius: 3px;
	-webkit-border-bottom-left-radius: 3px;
	border-top-left-radius: 3px;
	border-bottom-left-radius: 3px;
}

#post-body ul.category-tabs li.tabs a,
#post-body ul.add-menu-item-tabs li.tabs a {
	font-weight: bold;
	text-decoration: none;
}

.categorydiv div.tabs-panel,
.customlinkdiv div.tabs-panel,
.posttypediv div.tabs-panel,
.taxonomydiv div.tabs-panel,
#linkcategorydiv div.tabs-panel {
	height: 200px;
	overflow: auto;
	padding: 0.5em 0.9em;
	border-style: solid;
	border-width: 1px;
}

.nav-menus-php .customlinkdiv div.tabs-panel,
.nav-menus-php .posttypediv div.tabs-panel,
.nav-menus-php .taxonomydiv div.tabs-panel {
	height: auto;
	max-height: 205px;
}

div.tabs-panel-active {
	display:block;
}

div.tabs-panel-inactive {
	display:none;
}

#post-body .categorydiv div.tabs-panel,
.taxonomy div.tabs-panel,
#post-body #linkcategorydiv div.tabs-panel {
	margin: 0 5px 0 125px;
}

.categorydiv ul,
.customlinkdiv ul,
.posttypediv ul,
.taxonomydiv ul,
#linkcategorydiv ul {
	list-style: none;
	padding: 0;
	margin: 0;
}

#front-page-warning,
#front-static-pages ul,
ul.export-filters,
.inline-editor ul.cat-checklist ul,
.categorydiv ul.categorychecklist ul,
.customlinkdiv ul.categorychecklist ul,
.posttypediv ul.categorychecklist ul,
.taxonomydiv ul.categorychecklist ul,
#linkcategorydiv ul.categorychecklist ul {
	margin-left: 18px;
}

ul.categorychecklist li {
	margin: 0;
	padding: 0;
	line-height: 19px;
	word-wrap: break-word;
}

.categorydiv .tabs-panel,
.customlinkdiv .tabs-panel,
.posttypediv .tabs-panel,
.taxonomydiv .tabs-panel {
	border-width: 3px;
	border-style: solid;
}

.form-wrap p,
.form-wrap label {
	font-size: 11px;
}

.form-wrap label {
	display: block;
	padding: 2px;
	font-size: 12px;
}

.form-field input,
.form-field textarea {
	border-style: solid;
	border-width: 1px;
	width: 95%;
}

p.description,
.form-wrap p {
	margin: 2px 0 5px;
}

p.help,
p.description,
span.description,
.form-wrap p {
	font-size: 12px;
	font-style: italic;
	font-family: sans-serif;
}

.form-wrap .form-field {
	margin: 0 0 10px;
	padding: 8px;
}

.col-wrap h3 {
	margin: 12px 0;
	font-size: 1.1em;
}

.col-wrap p.submit {
	margin-top: -10px;
}


/*------------------------------------------------------------------------------
  13.0 - Tags
------------------------------------------------------------------------------*/

#poststuff .taghint {
	color: #aaa;
	margin: 15px 0 -24px 12px;
}

#poststuff .tagsdiv .howto {
	margin: 0 0 6px 8px;
}

.ajaxtag .newtag {
	position: relative;
}

.tagsdiv .newtag {
	width: 180px;
}

.tagsdiv .the-tags {
	display: block;
	height: 60px;
	margin: 0 auto;
	overflow: auto;
	width: 260px;
}

#post-body-content .tagsdiv .the-tags {
	margin: 0 5px;
}

p.popular-tags {
	-webkit-border-radius: 8px;
	border-radius: 8px;
	border-width: 1px;
	border-style: solid;
	line-height: 2em;
	max-width: 1000px;
	padding: 8px 12px 12px;
	text-align: justify;
}

p.popular-tags a {
	padding: 0 3px;
}

.tagcloud {
	width: 97%;
	margin: 0 0 40px;
	text-align: justify;
}

.tagcloud h3 {
	margin: 2px 0 12px;
}

.ac_results {
	padding: 0;
	margin: 0;
	list-style: none;
	position: absolute;
	z-index: 10000;
	display: none;
	border-width: 1px;
	border-style: solid;
}

.ac_results li {
	padding: 2px 5px;
	white-space: nowrap;
	text-align: left;
}

.ac_over {
	cursor: pointer;
}

.ac_match {
	text-decoration: underline;
}


/*------------------------------------------------------------------------------
  14.0 - Media Screen
------------------------------------------------------------------------------*/

#wpbody-content #media-items .describe {
	border-collapse: collapse;
	width: 100%;
	border-top-style: solid;
	border-top-width: 1px;
	clear: both;
	cursor: default;
	padding: 5px;
}

#wpbody-content .describe th {
	vertical-align: top;
	text-align: left;
	padding: 10px;
	width: 140px;
}

#wpbody-content .describe .media-item-info tr {
	background-color: transparent;
}

#wpbody-content .describe .media-item-info td {
	padding: 4px 10px 0;
}

.describe .media-item-info .A1B1 {
	padding: 0 0 0 10px;
}

#wpbody-content .filename {
	padding: 0 10px;
}

#wpbody-content .media-item .thumbnail {
	max-height: 128px;
	max-width: 128px;
}

#wpbody-content #async-upload-wrap a {
	display: none;
}

.media-upload-form td label {
	margin-right: 6px;
	margin-left: 2px;
}

.media-upload-form .align .field label {
	display: inline;
	padding: 0 0 0 23px;
	margin: 0 1em 0 3px;
	font-weight: bold;
}

.media-upload-form tr.image-size label {
	margin: 0 0 0 5px;
	font-weight: bold;
}

.media-upload-form th.label label {
	font-weight: bold;
	margin: 0.5em;
	font-size: 13px;
}

.media-upload-form th.label label span {
	padding: 0 5px;
}

abbr.required {
	border: medium none;
	text-decoration: none;
}

#wpbody-content .describe input[type="text"],
#wpbody-content .describe textarea {
	width: 460px;
}

#wpbody-content .describe p.help {
	margin: 0;
	padding: 0 0 0 5px;
}

.media-item .error-div a.dismiss,
.describe-toggle-on,
.describe-toggle-off {
	display: block;
	line-height: 36px;
	float: right;
	margin-right: 20px;
}

.describe-toggle-off {
	display: none;
}

#wpbody-content .media-item {
	border-bottom-style: solid;
	border-bottom-width: 1px;
	min-height: 36px;
	position: relative;
	width: 100%;
}

#wpbody-content .media-single .media-item {
	border-bottom-style: none;
	border-bottom-width: 0;
}

#wpbody-content #media-items {
	border-style: solid solid none;
	border-width: 1px;
	width: 670px;
}

#wpbody-content #media-items:empty {
	border: 0 none;
}

#wpbody-content #media-items .filename {
	line-height: 36px;
	overflow: hidden;
}

.media-item .error-div {
	padding-left: 10px;
}

.media-item .pinkynail {
	float: left;
	margin: 2px;
	max-width: 40px;
	max-height: 32px;
}

.media-item .startopen,
.media-item .startclosed {
	display: none;
}

.media-item .original {
	position: relative;
	height: 34px;
	width: 503px;
}

.media-item .percent {
	font-weight: bold;
}

.crunching {
	display: block;
	line-height: 32px;
	text-align: right;
	margin-right: 5px;
}

.progress {
	position: relative;
	margin-bottom: -36px;
	height: 36px;
}

.bar {
	width: 0;
	height: 100%;
	border-right-width: 3px;
	border-right-style: solid;
}

.upload-php .fixed .column-parent {
	width: 25%;
}


/*------------------------------------------------------------------------------
  14.1 - Media Uploader
------------------------------------------------------------------------------*/

.find-box {
	width: 500px;
	height: 300px;
	overflow: hidden;
	padding: 33px 5px 40px;
	position: absolute;
	z-index: 1000;
}

.find-box-head {
	cursor: move;
	font-weight: bold;
	height: 2em;
	line-height: 2em;
	padding: 1px 12px;
	position: absolute;
	top: 5px;
	width: 100%;
}

.find-box-inside {
	overflow: auto;
	width: 100%;
	height: 100%;
}

.find-box-search {
	padding: 12px;
	border-width: 1px;
	border-style: none none solid;
}

#find-posts-response {
	margin: 8px 0;
	padding: 0 1px;
}

#find-posts-response table {
	width: 100%;
}

#find-posts-response .found-radio {
	padding: 5px 0 0 8px;
	width: 15px;
}

.find-box-buttons {
	width: 480px;
	margin: 8px;
}

.find-box-search label {
	padding-right: 6px;
}

.find-box #resize-se {
	position: absolute;
	right: 1px;
	bottom: 1px;
}

ul#dismissed-updates {
	display: none;
}

form.upgrade {
	margin-top: 8px;
}

form.upgrade .hint {
	font-style: italic;
	font-size: 85%;
	margin: -0.5em 0 2em 0;
}

#poststuff .inside .the-tagcloud {
	margin: 5px 0 10px;
	padding: 8px;
	border-width: 1px;
	border-style: solid;
	line-height: 1.8em;
	word-spacing: 3px;
	-webkit-border-radius: 6px;
	border-radius: 6px;
}

.drag-drop #drag-drop-area {
	border: 4px dashed #DDDDDD;
    height: 200px;
}

.drag-drop .drag-drop-inside {
	padding-top: 60px;
}

.drag-drop .drag-drop-inside p {
	text-align: center;
}

.dragdrop-info {
	color: #aaa;
	display: none;
	font-size: 24px;
	margin: 10px 0;
}

.drag-drop .dragdrop-info {
	display: block;
}


/*------------------------------------------------------------------------------
  14.2 - Image Editor
------------------------------------------------------------------------------*/

.describe .image-editor {
	vertical-align: top;
}

.imgedit-wrap {
	position: relative;
}

.imgedit-settings p {
	margin: 8px 0;
}

.describe .imgedit-wrap table td {
	vertical-align: top;
	padding-top: 0;
}

.imgedit-wrap p,
.describe .imgedit-wrap table td {
	font-size: 11px;
	line-height: 18px;
}

.describe .imgedit-wrap table td.imgedit-settings {
	padding: 0 5px;
}

td.imgedit-settings input {
	vertical-align: middle;
}

.imgedit-wait {
	position: absolute;
	top: 0;
	background: #FFFFFF url(../images/wpspin_light.gif) no-repeat scroll 22px 10px;
	opacity: 0.7;
	filter: alpha(opacity=70);
	width: 100%;
	height: 500px;
	display: none;
}

.media-disabled,
.imgedit-settings .disabled  {
	color: grey;
}

.imgedit-wait-spin {
	padding: 0 4px 4px;
	vertical-align: bottom;
	visibility: hidden;
}

.imgedit-menu {
	margin: 0 0 12px;
	min-width: 300px;
}

.imgedit-menu div {
	float: left;
	width: 32px;
	height: 32px;
}

.imgedit-crop-wrap {
	position: relative;
}

.imgedit-crop {
	background: transparent url(../images/imgedit-icons.png) no-repeat scroll -9px -31px;
	margin: 0 8px 0 0;
}

.imgedit-crop.disabled:hover {
	background-position: -9px -31px;
}

.imgedit-crop:hover {
	background-position: -9px -1px;
}

.imgedit-rleft {
	background: transparent url(../images/imgedit-icons.png) no-repeat scroll -46px -31px;
	margin: 0 3px;
}

.imgedit-rleft.disabled:hover {
	background-position: -46px -31px;
}

.imgedit-rleft:hover {
	background-position: -46px -1px;
}

.imgedit-rright {
	background: transparent url(../images/imgedit-icons.png) no-repeat scroll -77px -31px;
	margin: 0 8px 0 3px;
}

.imgedit-rright.disabled:hover {
	background-position: -77px -31px;
}

.imgedit-rright:hover {
	background-position: -77px -1px;
}

.imgedit-flipv {
	background: transparent url(../images/imgedit-icons.png) no-repeat scroll -115px -31px;
	margin: 0 3px;
}

.imgedit-flipv.disabled:hover {
	background-position: -115px -31px;
}

.imgedit-flipv:hover {
	background-position: -115px -1px;
}

.imgedit-fliph {
	background: transparent url(../images/imgedit-icons.png) no-repeat scroll -147px -31px;
	margin: 0 8px 0 3px;
}

.imgedit-fliph.disabled:hover {
	background-position: -147px -31px;
}

.imgedit-fliph:hover {
	background-position: -147px -1px;
}

.imgedit-undo {
	background: transparent url(../images/imgedit-icons.png) no-repeat scroll -184px -31px;
	margin: 0 3px;
}

.imgedit-undo.disabled:hover {
	background-position: -184px -31px;
}

.imgedit-undo:hover {
	background-position: -184px -1px;
}

.imgedit-redo {
	background: transparent url(../images/imgedit-icons.png) no-repeat scroll -215px -31px;
	margin: 0 8px 0 3px;
}

.imgedit-redo.disabled:hover {
	background-position: -215px -31px;
}

.imgedit-redo:hover {
	background-position: -215px -1px;
}

.imgedit-applyto img {
	margin: 0 8px 0 0;
}

.imgedit-group-top {
	margin: 5px 0;
}

.imgedit-applyto .imgedit-label {
	padding: 2px 0 0;
	display: block;
}

.imgedit-help {
	display: none;
	font-style: italic;
	margin-bottom: 8px;
}

.imgedit-help ul li {
	font-size: 11px;
}

a.imgedit-help-toggle {
	text-decoration: none;
}

#wpbody-content .imgedit-response div {
	width: 600px;
	margin: 8px;
}

.form-table td.imgedit-response {
	padding: 0;
}

.imgedit-submit {
	margin: 8px 0;
}

.imgedit-submit-btn {
	margin-left: 20px;
}

.imgedit-wrap .nowrap {
	white-space: nowrap;
}

span.imgedit-scale-warn {
	color: red;
	font-size: 20px;
	font-style: normal;
	visibility: hidden;
	vertical-align: middle;
}

.imgedit-group {
	border-width: 1px;
	border-style: solid;
	-webkit-border-radius: 8px;
	border-radius: 8px;
	margin-bottom: 8px;
	padding: 2px 10px;
}


/*------------------------------------------------------------------------------
  15.0 - Comments Screen
------------------------------------------------------------------------------*/

.form-table {
	border-collapse: collapse;
	margin-top: 0.5em;
	width: 100%;
	margin-bottom: -8px;
	clear: both;
}

.form-table td {
	margin-bottom: 9px;
	padding: 8px 10px;
	line-height: 20px;
	font-size: 12px;
}

.form-table th,
.form-wrap label {
	font-weight: normal;
	text-shadow: #fff 0 1px 0;
}

.form-table th {
	vertical-align: top;
	text-align: left;
	padding: 10px;
	width: 200px;
}

.form-table th.th-full {
	width: auto;
}

.form-table div.color-option {
	display: block;
	clear: both;
	margin-top: 12px;
}

.form-table input.tog {
	margin-top: 2px;
	margin-right: 2px;
	float: left;
}

.form-table td p {
	margin-top: 4px;
}

.form-table table.color-palette {
	vertical-align: bottom;
	float: left;
	margin: -12px 3px 11px;
}

.form-table .color-palette td {
	border-width: 1px 1px 0;
	border-style: solid solid none;
	height: 10px;
	line-height: 20px;
	width: 10px;
}

.commentlist li {
	padding: 1em 1em .2em;
	margin: 0;
	border-bottom-width: 1px;
	border-bottom-style: solid;
}

.commentlist li li {
	border-bottom: 0;
	padding: 0;
}

.commentlist p {
	padding: 0;
	margin: 0 0 .8em;
}

/* reply to comments */
#replyrow input {
	border-width: 1px;
	border-style: solid;
}

#replyrow td {
	padding: 2px;
}

#replysubmit {
	margin: 0;
	padding: 0 7px 3px;
	text-align: center;
}

#replysubmit img.waiting,
.inline-edit-save img.waiting {
	padding: 4px 10px 0;
	vertical-align: top;
	float: right;
}

#replysubmit .button {
	margin-right: 5px;
}

#replysubmit .error {
	color: red;
	line-height: 21px;
	text-align: center;
	vertical-align: center;
}

#replyrow h5 {
	margin: .2em 0 0;
	padding: 0 5px;
	line-height: 1.4em;
	font-size: 1em;
}

#edithead .inside {
	float: left;
	padding: 3px 0 2px 5px;
	margin: 0;
	text-align: center;
}

#edithead .inside input {
	width: 180px;
}

#edithead label {
	padding: 2px 0;
}

#replycontainer {
	padding: 5px;
}

#replycontent {
	height: 120px;
}

.comment-ays {
	margin-bottom: 0;
	border-style: solid;
	border-width: 1px;
}

.comment-ays th {
	border-right-style: solid;
	border-right-width: 1px;
}

.trash-undo-inside,
.spam-undo-inside {
	margin: 1px 8px 1px 0;
	line-height: 16px;
}

.spam-undo-inside .avatar,
.trash-undo-inside .avatar {
	height: 20px;
	width: 20px;
	margin-right: 8px;
	vertical-align: middle;
}

.stuffbox .editcomment {
	clear: none;
}

#comment-status-radio p {
	margin: 3px 0 5px;
}

#comment-status-radio input {
	margin: 2px 3px 5px 0;
	vertical-align: middle;
}

#comment-status-radio label {
	padding: 5px 0;
}

.commentlist .avatar {
	vertical-align: text-top;
}


/*------------------------------------------------------------------------------
  16.0 - Themes
------------------------------------------------------------------------------*/

.theme-install-php .tablenav {
	height:auto;
}

.available-theme {
	display: inline-block;
	margin-bottom: 10px;
	margin-right: 25px;
	overflow: hidden;
	padding: 20px;
	vertical-align: top;
	width: 240px;
}

.available-theme a.screenshot {
	width: 240px;
	height: 180px;
	display: block;
	border-width: 1px;
	border-style: solid;
	margin-bottom: 10px;
	overflow: hidden;
}

.available-theme img {
	width: 240px;
}

.available-theme h3 {
	margin: 15px 0 5px;
}

#current-theme {
	margin: 1em 0 1.5em;
}

#current-theme a {
	border-bottom: none;
}

#current-theme h3 {
	font-size: 17px;
	font-weight: normal;
	margin: 0;
}

#current-theme .theme-description {
	margin-top: 5px;
}

#current-theme img {
	float: left;
	border-width: 1px;
	border-style: solid;
	margin-right: 1em;
	margin-bottom: 1.5em;
	width: 150px;
}

.theme-options span {
	text-transform: uppercase;
	font-size: 13px;
}

.theme-options a {
	font-size: 15px;
}

#TB_window #TB_title a.tb-theme-preview-link,
#TB_window #TB_title a.tb-theme-preview-link:visited {
	font-weight: bold;
	text-decoration: none;
}

#TB_window #TB_title {
	background-color: #222;
	color: #cfcfcf;
}

#broken-themes {
	text-align: left;
	width: 50%;
	border-spacing: 3px;
	padding: 3px;
}

.theme-install-php h4 {
	margin: 2.5em 0 8px;
}


/*------------------------------------------------------------------------------
  16.1 - Custom Header Screen
------------------------------------------------------------------------------*/

.appearance_page_custom-header #headimg {
	border: 1px solid #DFDFDF;
	min-height: 100px;
	width: 100%;
}

.appearance_page_custom-header #upload-form p label {
	font-size: 12px;
}

.appearance_page_custom-header .available-headers .default-header {
	float: left;
	margin: 0 20px 20px 0;
}

.appearance_page_custom-header .random-header {
	clear: both;
	margin: 0 20px 20px 0;
	vertical-align: middle;
}

.appearance_page_custom-header .available-headers label input,
.appearance_page_custom-header .random-header label input {
	margin-right: 10px;
}

.appearance_page_custom-header .available-headers label img {
	vertical-align: middle;
}


/*------------------------------------------------------------------------------
  16.2 - Custom Background Screen
------------------------------------------------------------------------------*/

div#custom-background-image {
	min-height: 100px;
	border: 1px solid #dfdfdf;
}

div#custom-background-image img {
	max-width: 400px;
	max-height: 300px;
}


/*------------------------------------------------------------------------------
  16.3 - Tabbed Admin Screen Interface (Experimental)
------------------------------------------------------------------------------*/

.nav-tab {
	border-style: solid;
	border-color: #dfdfdf #dfdfdf #fff;
	border-width: 1px 1px 0;
	color: #aaa;
	text-shadow: #fff 0 1px 0;
	font-size: 12px;
	line-height: 16px;
	display: inline-block;
	padding: 4px 14px 6px;
	text-decoration: none;
	margin: 0 6px -1px 0;
	-webkit-border-top-left-radius: 3px;
	-webkit-border-top-right-radius: 3px;
	border-top-left-radius: 3px;
	border-top-right-radius: 3px;
}

.nav-tab-active {
	border-width: 1px;
	color: #464646;
}

.nav-tab:hover,
.nav-tab-active {
	border-color: #ccc #ccc #fff;
}

h2.nav-tab-wrapper, h3.nav-tab-wrapper {
	border-bottom: 1px solid #ccc;
	padding-bottom: 0;
}

h2 .nav-tab {
	padding: 4px 10px 6px;
	font-weight: 200;
	font-size: 20px;
	line-height: 24px;

}


/*------------------------------------------------------------------------------
  17.0 - Plugins
------------------------------------------------------------------------------*/

.plugins .name,
#pass-strength-result.strong,
#pass-strength-result.short,
.button-highlighted,
input.button-highlighted,
#quicktags #ed_strong,
#ed_reply_toolbar #ed_reply_strong {
	font-weight: bold;
}

.plugins p {
	margin: 0 4px;
	padding: 0;
}

.plugins .desc p {
	margin: 0 0 8px;
}

.plugins td.desc {
	line-height: 1.5em;
}

.plugins .desc ul,
.plugins .desc ol {
	margin: 0 0 0 2em;
}

.plugins .desc ul {
	list-style-type: disc;
}

.plugins .row-actions-visible {
	padding: 0;
}

.plugins tbody th.check-column {
	padding: 7px 0;
}

.plugins .inactive td,
.plugins .inactive th,
.plugins .active td,
.plugins .active th {
	border-top-style: solid;
	border-top-width: 1px;
	padding: 5px 7px 0;
}

#wpbody-content .plugins .plugin-title, #wpbody-content .plugins .theme-title {
	padding-right: 12px;
	white-space:nowrap;
}

.plugins .second, .plugins .row-actions-visible {
	padding: 0 0 5px;
}

.plugins-php .widefat tfoot th,
.plugins-php .widefat tfoot td {
	border-top-style: solid;
	border-top-width: 1px;
}

.plugin-update-tr .update-message {
	margin: 5px;
	padding: 3px 5px;
}

.plugin-install-php h4 {
	margin: 2.5em 0 8px;
}


/*------------------------------------------------------------------------------
  18.0 - Users
------------------------------------------------------------------------------*/

#profile-page .form-table textarea {
	width: 500px;
	margin-bottom: 6px;
}

#profile-page .form-table #rich_editing {
	margin-right: 5px
}

#your-profile legend {
	font-size: 22px;
}

#your-profile #rich_editing {
	border: none;
}

#display_name {
	width: 15em;
}

#createuser .form-field input {
	width: 25em;
}

/*------------------------------------------------------------------------------
  19.0 - Tools
------------------------------------------------------------------------------*/

.pressthis {
	margin: 20px 0;
}

.pressthis a {
	display: inline-block;
	width: 113px;
	position: relative;
	cursor: move;
	color: #333;
	background: #dfdfdf;
	background-image: -webkit-gradient(
		linear,
		left bottom,
		left top,
		color-stop(0.07, rgb(230,230,230)),
		color-stop(0.77, rgb(216,216,216))
	);
	background-image: -moz-linear-gradient(
		center bottom,
		rgb(230,230,230) 7%,
		rgb(216,216,216) 77%
	);
	background-repeat: no-repeat;
	background-image-position: 10px 8px;
	-webkit-border-radius: 5px;
	border-radius: 5px;
	border: 1px #b4b4b4 solid;
	font-style: normal;
	line-height: 16px;
	font-size: 14px;
	text-decoration: none;
	text-shadow: #fff 0 1px 0px;
}

.pressthis a:hover,
.pressthis a:active {
	color: #333
}

.pressthis a:hover:after {
	transform: skew(20deg) rotate(9deg);
	-webkit-transform: skew(20deg) rotate(9deg);
	-moz-transform: skew(20deg) rotate(9deg);
	box-shadow: 0 10px 8px rgba(0, 0, 0, 0.7);
	-webkit-box-shadow: 0 10px 8px rgba(0, 0, 0, 0.7);
	-moz-box-shadow: 0 10px 8px rgba(0, 0, 0, 0.7);
}

.pressthis a span {
	background: url(../images/press-this.png) no-repeat -45px 5px ;
	padding: 8px 0 8px 32px;
	display: inline-block;
}

.pressthis a:after {
	content: '';
	width: 70%;
	height: 55%;
	z-index: -1;
	position: absolute;
	right: 10px;
	bottom: 9px;
	background: transparent;
	transform: skew(20deg) rotate(6deg);
	-webkit-transform: skew(20deg) rotate(6deg);
	-moz-transform: skew(20deg) rotate(6deg);
	box-shadow: 0 10px 8px rgba(0, 0, 0, 0.6);
	-webkit-box-shadow: 0 10px 8px rgba(0, 0, 0, 0.6);
	-moz-box-shadow: 0 10px 8px rgba(0, 0, 0, 0.6);
}


/*------------------------------------------------------------------------------
  20.0 - Settings
------------------------------------------------------------------------------*/

#utc-time, #local-time {
	padding-left: 25px;
	font-style: italic;
	font-family: sans-serif;
}

.defaultavatarpicker .avatar {
	margin: 2px 0;
	vertical-align: middle;
}


/*------------------------------------------------------------------------------
  21.0 - Admin Footer
------------------------------------------------------------------------------*/

#footer {
	position: absolute;
	bottom: 0;
	left: 0;
	right: 0;
	padding: 10px 0;
	margin-right: 20px;
	border-top-width: 1px;
	border-top-style: solid;
}

#footer p {
	margin: 0;
	line-height: 20px;
}

#footer a {
	text-decoration: none;
}

#footer a:hover {
	text-decoration: underline;
}


/*------------------------------------------------------------------------------
  22.0 - Misc
------------------------------------------------------------------------------*/

#excerpt, .attachmentlinks {
	margin: 0;
	height: 4em;
	width: 98%;
}

#template div {
	margin-right: 190px;
}

p.pagenav {
	margin: 0;
	display: inline;
}

.pagenav span {
	font-weight: bold;
	margin: 0 6px;
}

.row-title {
	font-size: 13px !important;
	font-weight: bold;
}

.column-author img, .column-username img {
	float: left;
	margin-right: 10px;
	margin-top: 1px;
}

.row-actions {
	visibility: hidden;
	padding: 2px 0 0;
}

tr:hover .row-actions,
div.comment-item:hover .row-actions {
	visibility: visible;
}

.row-actions-visible {
	padding: 2px 0 0;
}

.form-table .pre {
	padding: 8px;
	margin: 0;
}

table.form-table td .updated {
	font-size: 13px;
}

.tagchecklist {
	margin-left: 14px;
	font-size: 12px;
	overflow: auto;
}
.tagchecklist strong {
	margin-left: -8px;
	position: absolute;
}
.tagchecklist span {
	margin-right: 25px;
	display: block;
	float: left;
	font-size: 11px;
	line-height: 1.8em;
	white-space: nowrap;
	cursor: default;
}
.tagchecklist span a {
	margin: 6px 0pt 0pt -9px;
	cursor: pointer;
	width: 10px;
	height: 10px;
	display: block;
	float: left;
	text-indent: -9999px;
	overflow: hidden;
	position: absolute;
}

#poststuff h2 {
	margin-top: 20px;
	font-size: 1.5em;
	margin-bottom: 15px;
	padding: 0 0 3px;
	clear: left;
}

#poststuff h3,
.metabox-holder h3 {
	font-size: 15px;
	font-weight: normal;
	padding: 7px 10px;
	margin: 0;
	line-height: 1;
}

#poststuff .inside {
	margin: 6px 0 8px;
}

#post-visibility-select,
#post-formats-select {
	line-height: 1.5em;
	margin-top: 3px;
}

#poststuff #submitdiv .inside {
	margin: 0;
	padding: 0;
}

#titlediv, #poststuff .postarea {
	margin-bottom: 20px;
}

td.post-title strong, td.plugin-title strong {
	display: block;
	margin-bottom: .2em;
}

td.post-title p, td.plugin-title p {
	margin: 6px 0;
}

#templateside ul li a {
	text-decoration: none;
}

.tool-box .title {
	margin: 8px 0;
	font-size: 18px;
	font-weight: normal;
	line-height: 24px;
}

#sidemenu {
	margin: -30px 15px 0 315px;
	list-style: none;
	position: relative;
	float: right;
	padding-left: 10px;
	font-size: 12px;
}

#sidemenu a {
	padding: 0 7px;
	display: block;
	float: left;
	line-height: 28px;
	border-top-width: 1px;
	border-top-style: solid;
	border-bottom-width: 1px;
	border-bottom-style: solid;
}

#sidemenu li {
	display: inline;
	line-height: 200%;
	list-style: none;
	text-align: center;
	white-space: nowrap;
	margin: 0;
	padding: 0;
}

#sidemenu a.current {
	font-weight: normal;
	padding-left: 6px;
	padding-right: 6px;
	-webkit-border-top-left-radius: 3px;
	-webkit-border-top-right-radius: 3px;
	border-top-left-radius: 3px;
	border-top-right-radius: 3px;
	border-width: 1px;
	border-style: solid;
}

#sidemenu li a .count-0 {
	display: none;
}

.plugin-install #description, .plugin-install-network #description {
	width: 60%;
}

table .vers,
table .column-visible,
table .column-rating {
	text-align: left;
}

/* Scrollbar fix for bulk upgrade iframe */
body.iframe {
	height: 98%;
}


/* - Only used once or twice in all of WP - deprecate for global style
------------------------------------------------------------------------------*/
td.media-icon {
	text-align: center;
	width: 80px;
	padding-top: 8px;
	padding-bottom: 8px;
}

td.media-icon img {
	max-width: 80px;
	max-height: 60px;
}

.screen-per-page {
	width: 3em;
}

.list-ajax-loading {
	float: right;
	margin-right: 9px;
	margin-top: -1px;
}

.tablenav .list-ajax-loading {
	margin-top: 7px;
}

#howto {
	font-size: 11px;
	margin: 0 5px;
	display: block;
}

.importers td {
	padding-right: 14px;
}

.importers {
	font-size: 16px;
	width: auto;
}

#namediv table {
	width: 100%;
}

#namediv td.first {
	width: 10px;
	white-space: nowrap;
}

#namediv input {
	width: 98%;
}

#namediv p {
	margin: 10px 0;
}

#submitdiv h3 {
	margin-bottom: 0 !important;
}

/* - Used - but could/should be deprecated with a CSS reset
------------------------------------------------------------------------------*/
.zerosize {
	height: 0;
	width: 0;
	margin: 0;
	border: 0;
	padding: 0;
	overflow: hidden;
	position: absolute;
}

br.clear {
	height: 2px;
	line-height: 2px;
}

.checkbox {
	border: none;
	margin: 0;
	padding: 0;
}

fieldset {
	border: 0;
	padding: 0;
	margin: 0;
}

.post-categories {
	display: inline;
	margin: 0;
	padding: 0;
}

.post-categories li {
	display: inline;
}





/*-----------------------------------------------------------------------------
 MERGED
-------------------------------------------------------------------------------*/

/* dashboard */
.edit-box {
	display: none;
}

h3:hover .edit-box {
	display: inline;
}

.index-php form .input-text-wrap {
	background: #fff;
	border-style: solid;
	border-width: 1px;
	padding: 2px 3px;
	border-color: #ccc;
}

#dashboard-widgets form .input-text-wrap input {
	border: 0 none;
	outline: none;
	margin: 0;
	padding: 0;
	width: 99%;
	color: #333;
}

form .textarea-wrap {
	background: #fff;
	border-style: solid;
	border-width: 1px;
	padding: 2px;
	border-color: #ccc;
}

#dashboard-widgets form .textarea-wrap textarea {
	border: 0 none;
	padding: 0;
	outline: none;
	width: 99%;
	-moz-box-sizing: border-box;
	-webkit-box-sizing: border-box;
	box-sizing: border-box;
}

#dashboard-widgets .postbox form .submit {
	float: none;
	margin: .5em 0 0;
	padding: 0;
	border: none;
}

#dashboard-widgets-wrap #dashboard-widgets .postbox form .submit input {
	margin: 0;
}

#dashboard-widgets-wrap #dashboard-widgets .postbox form .submit #publish {
	min-width: 0;
}

div.postbox div.inside {
	margin: 10px 0;
	position: relative;
}

#dashboard-widgets a {
	text-decoration: none;
}

#dashboard-widgets h3 a {
	text-decoration: underline;
}

#dashboard-widgets h3 .postbox-title-action {
	position: absolute;
	right: 30px;
	padding: 0;
	top: 5px;
}

#dashboard-widgets h4 {
	font-weight: normal;
	font-size: 13px;
	margin: 0 0 .2em;
	padding: 0;
}

/* Right Now */
#dashboard_right_now p.sub,
#dashboard_right_now .table, #dashboard_right_now .versions {
	margin: -12px;
}

#dashboard_right_now .inside {
	font-size: 12px;
	padding-top: 20px;
}

#dashboard_right_now p.sub {
	padding: 5px 0 15px;
	color: #8f8f8f;
	font-size: 14px;
	position: absolute;
	top: -17px;
	left: 15px;
}

#dashboard_right_now .table {
	margin: 0;
	padding: 0;
	position: relative;
}

#dashboard_right_now .table_content {
	float: left;
	border-top: #ececec 1px solid;
	width: 45%;
}

#dashboard_right_now .table_discussion {
	float: right;
	border-top: #ececec 1px solid;
	width: 45%;
}

#dashboard_right_now table td {
	padding: 3px 0;
	white-space: nowrap;
}

#dashboard_right_now table tr.first td {
	border-top: none;
}

#dashboard_right_now td.b {
	padding-right: 6px;
	text-align: right;
	font-size: 14px;
	width: 1%;
}

#dashboard_right_now td.b a {
	font-size: 18px;
}

#dashboard_right_now td.b a:hover {
	color: #d54e21;
}

#dashboard_right_now .t {
	font-size: 12px;
	padding-right: 12px;
	padding-top: 6px;
	color: #777;
}

#dashboard_right_now .t a {
	white-space: nowrap;
}

#dashboard_right_now .spam {
	color: red;
}

#dashboard_right_now .waiting {
	color: #e66f00;
}

#dashboard_right_now .approved {
	color: green;
}

#dashboard_right_now .versions {
	padding: 6px 10px 12px;
	clear: both;
}

#dashboard_right_now .versions .b {
	font-weight: bold;
}

#dashboard_right_now a.button {
	float: right;
	clear: right;
	position: relative;
	top: -5px;
}

/* Recent Comments */
#dashboard_recent_comments h3 {
	margin-bottom: 0;
}

#dashboard_recent_comments .inside {
	margin-top: 0;
}

#dashboard_recent_comments .comment-meta .approve {
	font-style: italic;
	font-family: sans-serif;
	font-size: 10px;
}

#dashboard_recent_comments .subsubsub {
	float: none;
	white-space: normal;
}

#the-comment-list {
	position: relative;
}

#the-comment-list .comment-item {
	padding: 1em 10px;
	border-top: 1px solid;
}

#the-comment-list .pingback {
	padding-left: 9px !important;
}

#the-comment-list .comment-item,
#the-comment-list #replyrow {
	margin: 0 -10px;
}

#the-comment-list .comment-item:first-child {
	border-top: none;
}

#the-comment-list .comment-item .avatar {
	float: left;
	margin: 0 10px 5px 0;
}

#the-comment-list .comment-item h4 {
	line-height: 1.7em;
	margin-top: -0.4em;
	color: #777;
}

#the-comment-list .comment-item h4 cite {
	font-style: normal;
	font-weight: normal;
}

#the-comment-list .comment-item blockquote,
#the-comment-list .comment-item blockquote p {
	margin: 0;
	padding: 0;
	display: inline;
}

#dashboard_recent_comments #the-comment-list .trackback blockquote,
#dashboard_recent_comments #the-comment-list .pingback blockquote {
	display: block;
}

#the-comment-list .comment-item p.row-actions {
	margin: 3px 0 0;
	padding: 0;
	font-size: 12px;
}

/* QuickPress */
#dashboard_quick_press h4 {
	font-family: sans-serif;
	float: left;
	width: 5.5em;
	clear: both;
	font-weight: normal;
	text-align: right;
	padding-top: 4px;
	font-size: 12px;
}

#dashboard_quick_press h4 label {
	margin-right: 10px;
}

#dashboard_quick_press .input-text-wrap,
#dashboard_quick_press .textarea-wrap {
	margin: 0 0 1em 5em;
}

#dashboard_quick_press .wp-media-buttons {
	margin: 0 0 .5em 5em;
	padding: 0;
}

#dashboard_quick_press .wp-media-buttons a {
	color: #777;
}

#dashboard-widgets #dashboard_quick_press form p.submit {
	margin-left: 4.6em;
}

#dashboard-widgets #dashboard_quick_press form p.submit input {
	float: left;
}

#dashboard-widgets #dashboard_quick_press form p.submit #save-post {
	margin: 0 1em 0 10px;
}

#dashboard-widgets #dashboard_quick_press form p.submit #publish {
	float: right;
}

#dashboard-widgets #dashboard_quick_press form p.submit img.waiting {
	vertical-align: middle;
	visibility: hidden;
	margin: 4px 6px 0 0;
}

/* Recent Drafts */
#dashboard_recent_drafts ul {
	margin: 0;
	padding: 0;
	list-style: none;
}

#dashboard_recent_drafts ul li {
	margin-bottom: 1em;
}

#dashboard_recent_drafts h4 {
	line-height: 1.7em;
}

#dashboard_recent_drafts h4 abbr {
	font-weight: normal;
	font-family: sans-serif;
	font-size: 12px;
	color: #999;
	margin-left: 3px;
}

#dashboard_recent_drafts p {
	margin: 0;
	padding: 0;
}

/* Feeds */
.rss-widget ul {
	margin: 0;
	padding: 0;
	list-style: none;
}

a.rsswidget {
	font-size: 13px;
	line-height: 1.7em;
}

.rss-widget ul li {
	line-height: 1.5em;
	margin-bottom: 12px;
}

.rss-widget span.rss-date {
	color: #999;
	font-size: 12px;
	margin-left: 3px;
}

.rss-widget cite {
	display: block;
	text-align: right;
	margin: 0 0 1em;
	padding: 0;
}

.rss-widget cite:before {
	content: '\2014';
}

/* Plugins */
#dashboard_plugins h4 {
	line-height: 1.7em;
}

#dashboard_plugins h5 {
	font-weight: normal;
	font-size: 13px;
	margin: 0;
	display: inline;
	line-height: 1.4em;
}

#dashboard_plugins h5 a {
	line-height: 1.4em;
}

#dashboard_plugins .inside span {
	font-size: 12px;
	padding-left: 5px;
}

#dashboard_plugins p {
	margin: 0.3em 0 1.4em;
	line-height: 1.4em;
}

.dashboard-comment-wrap {
	overflow: hidden;
	word-wrap: break-word;
}

/* Browser Nag */
#dashboard_browser_nag a.update-browser-link {
	font-size: 1.2em;
	font-weight: bold;
}

#dashboard_browser_nag a {
	text-decoration: underline;
}

#dashboard_browser_nag p.browser-update-nag.has-browser-icon {
	padding-right: 125px;
}

#dashboard_browser_nag .browser-icon {
	margin-top: -35px;
}

#dashboard_browser_nag.postbox.browser-insecure {
	background-color: #ac1b1b;
	border-color: #ac1b1b;
}

#dashboard_browser_nag.postbox {
	background-color: #e29808;
	background-image: none;
	border-color: #edc048;
	-moz-box-shadow: none;
	-webkit-box-shadow: none;
	box-shadow: none;
	color: #fff;
}

#dashboard_browser_nag.postbox.browser-insecure h3 {
	border-bottom-color: #cd5a5a;
	color: #fff;
}

#dashboard_browser_nag.postbox h3 {
	border-bottom-color: #f6e2ac;
	text-shadow: none;
	-moz-box-shadow: none;
	-webkit-box-shadow: none;
	box-shadow: none;
	background: transparent none;
	color: #fff;
}

#dashboard_browser_nag a {
	color: #fff;
}

#dashboard_browser_nag.browser-insecure a.browse-happy-link,
#dashboard_browser_nag.browser-insecure a.update-browser-link {
	text-shadow: #871b15 0 1px 0;
}

#dashboard_browser_nag a.browse-happy-link,
#dashboard_browser_nag a.update-browser-link {
	text-shadow: #d29a04 0 1px 0;
}









/* login */

.login form {
	margin-left: 8px;
	padding: 26px 24px 46px;
	font-weight: normal;
	background: #fff;
	border: 1px solid #e5e5e5;
	-moz-box-shadow: rgba(200, 200, 200, 0.7) 0px 4px 10px -1px;
	-webkit-box-shadow: rgba(200, 200, 200, 0.7) 0px 4px 10px -1px;
	box-shadow: rgba(200, 200, 200, 0.7) 0px 4px 10px -1px;
}

.login form .forgetmenot {
	font-weight: normal;
	float: left;
	margin-bottom: 0;
}

.login .button-primary {
	padding: 3px 10px;
	float: right;
}

#login form p {
	margin-bottom: 0;
}

#login form p.submit {
	padding: 0;
}

.login label {
	color: #777;
	font-size: 14px;
}

.login form .forgetmenot label {
	font-size: 12px;
	line-height: 19px;
}

.login form p {
	margin-bottom: 24px;
}

.login h1 a {
	background: url(../images/logo-login.png) no-repeat top center;
	width: 326px;
	height: 67px;
	text-indent: -9999px;
	overflow: hidden;
	padding-bottom: 15px;
	display: block;
}

#login {
	width: 320px;
	padding: 7em 0 0;
	margin: auto;
}

#login_error,
.login .message {
	margin: 0 0 16px 8px;
	padding: 12px;
}

.login #nav,
.login #backtoblog {
	text-shadow: #fff 0 1px 0;
	margin: 0 0 0 16px;
	padding: 16px 16px 0;
}

#backtoblog {
	padding: 12px 16px 0;
}

.login form .input {
	font-weight: 200;
	font-size: 24px;
	width: 97%;
	padding: 3px;
	margin-top: 2px;
	margin-right: 6px;
	margin-bottom: 16px;
	border: 1px solid #e5e5e5;
	background: #fbfbfb;
	outline: none;
	-moz-box-shadow: inset 1px 1px 2px rgba(200, 200, 200, 0.2);
	-webkit-box-shadow: inset 1px 1px 2px rgba(200, 200, 200, 0.2);
	box-shadow: inset 1px 1px 2px rgba(200, 200, 200, 0.2);
}

.login input {
	color: #555;
}

.login #pass-strength-result {
	font-weight: bold;
	border-style: solid;
	border-width: 1px;
	margin: 12px 0 6px;
	padding: 6px 5px;
	text-align: center;
}





/* ms */
/* Dashboard: MS Specific Data */
#dashboard_right_now p.musub {
	margin-top: 12px;
	border-top: 1px solid #ececec;
	padding-left: 16px;
	position: static;
}

.rtl #dashboard_right_now p.musub {
	padding-left: 0;
	padding-right: 16px;
}

#dashboard_right_now td.b a.musublink {
	font-size: 16px;
}

#dashboard_right_now div.musubtable {
	border-top: none;
}

#dashboard_right_now div.musubtable .t {
	white-space: normal;
}

/* Background Color for Site Status */
.wp-list-table .site-deleted {
	background: #ff8573;
}
.wp-list-table .site-spammed {
	background: #faafaa;
}
.wp-list-table .site-archived {
	background: #ffebe8;
}
.wp-list-table .site-mature {
	background: #fecac2;
}







/* nav-menu */

#nav-menus-frame {
	margin-left: 300px;
}

#wpbody-content #menu-settings-column {
	display:inline;
	width:281px;
	margin-left: -300px;
	clear: both;
	float: left;
	padding-top: 24px;
}
	.no-js #wpbody-content #menu-settings-column {
		padding-top: 31px;
	}

#menu-settings-column .inside {
	clear: both;
}

.metabox-holder-disabled .postbox {
	opacity: 0.5;
	filter: alpha(opacity=50);
}

.metabox-holder-disabled .button-controls .select-all {
	display: none;
}
#wpbody {
	position: relative;
}

/* Menu Container */
#menu-management-liquid {
	float: left;
	min-width: 100%;
}

#menu-management {
	position: relative;
	margin-right: 20px;
	margin-top: -3px;
	width: 100%;
}

#menu-management .menu-edit {
	margin-bottom: 20px;
}

.nav-menus-php #post-body {
	padding: 10px;
	border-width: 1px 0;
	border-style: solid;
}

#nav-menu-header,
#nav-menu-footer {
	padding: 0 10px;
}

#nav-menu-header {
	border-bottom: 1px solid;
}

#nav-menu-footer {
	border-top: 1px solid;
}

.nav-menus-php #post-body div.updated,
.nav-menus-php #post-body div.error {
	margin: 0;
}

.nav-menus-php #post-body-content {
	position: relative;
}

#menu-management .menu-add-new abbr {
	font-weight:bold;
}

/* Menu Tabs */

#menu-management .nav-tabs-nav {
	margin: 0 20px;
}

#menu-management .nav-tabs-arrow {
	width: 10px;
	padding: 0 5px 4px;
	cursor: pointer;
	position: absolute;
	top: 0;
	line-height: 22px;
	font-size: 18px;
	text-shadow: 0 1px 0 #fff;
}

#menu-management .nav-tabs-arrow-left {
	left: 0;
}

#menu-management .nav-tabs-arrow-right {
	right: 0;
	text-align: right;
}

#menu-management .nav-tabs-wrapper {
	width: 100%;
	height: 28px;
	margin-bottom: -1px;
	overflow: hidden;
}

#menu-management .nav-tabs {
	padding-left: 20px;
	padding-right: 10px;
}

.js #menu-management .nav-tabs {
	float: left;
	margin-left: 0px;
	margin-right: -400px;
}

#menu-management .nav-tab {
	margin-bottom: 0;
	font-size: 14px;
}


#select-nav-menu-container {
	text-align: right;
	padding: 0 10px 3px 10px;
	margin-bottom: 5px;
}

#select-nav-menu {
	width: 100px;
	display: inline;
}

#menu-name-label {
	margin-top: -2px;
}

#wpbody .open-label {
	display: block;
	float:left;
}

#wpbody .open-label span {
	padding-right: 10px;
}

.js .input-with-default-title {
	font-style: italic;
}

#menu-management .inside {
	padding: 0 10px;
}

/* Add Menu Item Boxes */
.postbox .howto input {
	width: 180px;
	float: right;
}

.customlinkdiv .howto input {
	width: 200px;
}

#nav-menu-theme-locations .howto select {
	width: 100%;
}

#nav-menu-theme-locations .button-controls {
	text-align: right;
}

.add-menu-item-view-all {
	height: 400px;
}

/* Button Primary Actions */
#menu-container .submit {
	margin: 0px 0px 10px;
	padding: 0px;
}

.nav-menus-php .meta-sep,
.nav-menus-php .submitdelete,
.nav-menus-php .submitcancel {
	display: block;
	float: left;
	margin: 4px 0;
	line-height: 15px;
}

.meta-sep {
	padding: 0 2px;
}

#cancel-save {
	text-decoration: underline;
	font-size: 12px;
	margin-left: 20px;
	margin-top: 5px;
}

/* Button Secondary Actions */
.list-controls {
	float: left;
	margin-top: 5px;
}

.add-to-menu {
	float: right;
}

.postbox img.waiting {
	display: none;
	vertical-align: middle;
}

.button-controls {
	clear:both;
	margin: 10px 0;
}

.show-all,
.hide-all {
	cursor: pointer;
}

.hide-all {
	display: none;
}

/* Create Menu */
#menu-name {
	width: 270px;
}

#manage-menu .inside {
	padding: 0px 0px;
}

/* Custom Links */
#available-links dt {
	display: block;
}

#add-custom-link .howto {
	font-size: 12px;
}

#add-custom-link label span {
	display: block;
	float: left;
	margin-top: 5px;
	padding-right: 5px;
}

.menu-item-textbox {
	width: 180px;
}

.nav-menus-php .howto span {
	margin-top: 4px;
	display: block;
	float: left;
}

/* Menu item types */
.quick-search {
	width: 190px;
}

.nav-menus-php .list-wrap {
	display: none;
	clear: both;
	margin-bottom: 10px;
}

.nav-menus-php .list-container {
	max-height: 200px;
	overflow-y: auto;
	padding: 10px 10px 5px;
}

.nav-menus-php .postbox p.submit {
	margin-bottom: 0;
}

/* Listings */
.nav-menus-php .list li {
	display: none;
	margin: 0;
	margin-bottom: 5px;
}

.nav-menus-php .list li .menu-item-title {
	cursor: pointer;
	display: block;
}

.nav-menus-php .list li .menu-item-title input {
	margin-right: 3px;
	margin-top: -3px;
}

/* Nav Menu */
#menu-container .inside {
	padding-bottom: 10px;
}

.menu {
	padding-top:1em;
}

#menu-to-edit {
	padding: 1em 0;
}

.menu ul {
	width: 100%;
}

.menu li {
	margin-bottom: 0;
	position:relative;
}

.menu-item-bar {
	clear:both;
	line-height:1.5em;
	position:relative;
	margin: 13px 0 0 0;
}

.menu-item-handle {
	border: 1px solid #dfdfdf;
	position: relative;
	padding-left: 10px;
	height: auto;
	width: 400px;
	line-height: 35px;
	text-shadow: 0 1px 0 #FFFFFF;
	overflow: hidden;
	word-wrap: break-word;
}

#menu-to-edit .menu-item-invalid .menu-item-handle {
	background-color: #f6c9cc; /* Fallback */
	background-image: -ms-linear-gradient(bottom, #f6c9cc, #fdf8ff); /* IE10 */
	background-image: -moz-linear-gradient(bottom, #f6c9cc, #fdf8ff); /* Firefox */
	background-image: -o-linear-gradient(bottom, #f6c9cc, #fdf8ff); /* Opera */
	background-image: -webkit-gradient(linear, left bottom, left top, from(#f6c9cc), to(#fdf8ff)); /* old Webkit  */
	background-image: -webkit-linear-gradient(bottom, #f6c9cc, #fdf8ff); /* new Webkit */
	background-image: linear-gradient(bottom, #f6c9cc, #fdf8ff); /* proposed W3C Markup */
}

.menu-item-edit-active .menu-item-handle {
	-webkit-border-bottom-right-radius: 0;
	-webkit-border-bottom-left-radius: 0;
	border-bottom-right-radius: 0;
	border-bottom-left-radius: 0;
}

.no-js .menu-item-edit-active .item-edit {
	display: none;
}

.js .menu-item-handle {
	cursor: move;
}

.menu li.deleting .menu-item-handle {
	background-image: none;
	text-shadow: 0 0 0;
}

.menu-item-handle .item-title {
	font-size: 12px;
	font-weight: bold;
	padding: 7px 0;
	line-height: 20px;
	display:block;
	margin-right:13em;
}

/* Sortables */
li.menu-item.ui-sortable-helper dl {
	margin-top: 0;
}

li.menu-item.ui-sortable-helper .menu-item-transport dl {
		margin-top: 13px;
}

.menu .sortable-placeholder {
	height: 35px;
	width: 410px;
	margin-top: 13px;
}

/* WARNING: The factor of 30px is hardcoded into the nav-menus javascript. */
.menu-item-depth-0 { margin-left: 0px; }
.menu-item-depth-1 { margin-left: 30px; }
.menu-item-depth-2 { margin-left: 60px; }
.menu-item-depth-3 { margin-left: 90px; }
.menu-item-depth-4 { margin-left: 120px; }
.menu-item-depth-5 { margin-left: 150px; }
.menu-item-depth-6 { margin-left: 180px; }
.menu-item-depth-7 { margin-left: 210px; }
.menu-item-depth-8 { margin-left: 240px; }
.menu-item-depth-9 { margin-left: 270px; }
.menu-item-depth-10 { margin-left: 300px; }
.menu-item-depth-11 { margin-left: 330px; }

.menu-item-depth-0 .menu-item-transport { margin-left: 0px; }
.menu-item-depth-1 .menu-item-transport { margin-left: -30px; }
.menu-item-depth-2 .menu-item-transport { margin-left: -60px; }
.menu-item-depth-3 .menu-item-transport { margin-left: -90px; }
.menu-item-depth-4 .menu-item-transport { margin-left: -120px; }
.menu-item-depth-5 .menu-item-transport { margin-left: -150px; }
.menu-item-depth-6 .menu-item-transport { margin-left: -180px; }
.menu-item-depth-7 .menu-item-transport { margin-left: -210px; }
.menu-item-depth-8 .menu-item-transport { margin-left: -240px; }
.menu-item-depth-9 .menu-item-transport { margin-left: -270px; }
.menu-item-depth-10 .menu-item-transport { margin-left: -300px; }
.menu-item-depth-11 .menu-item-transport { margin-left: -330px; }

body.menu-max-depth-0 { min-width: 950px !important; }
body.menu-max-depth-1 { min-width: 980px !important; }
body.menu-max-depth-2 { min-width: 1010px !important; }
body.menu-max-depth-3 { min-width: 1040px !important; }
body.menu-max-depth-4 { min-width: 1070px !important; }
body.menu-max-depth-5 { min-width: 1100px !important; }
body.menu-max-depth-6 { min-width: 1130px !important; }
body.menu-max-depth-7 { min-width: 1160px !important; }
body.menu-max-depth-8 { min-width: 1190px !important; }
body.menu-max-depth-9 { min-width: 1220px !important; }
body.menu-max-depth-10 { min-width: 1250px !important; }
body.menu-max-depth-11 { min-width: 1280px !important; }

/* Menu item controls */
.item-type {
	font-size: 12px;
	padding-right: 10px;
}

.item-controls {
	font-size: 12px;
	position: absolute;
	right: 20px;
	top: -1px;
}

.item-controls a {
	text-decoration: none;
}

.item-controls a:hover {
	cursor: pointer;
}

.item-controls .item-order {
	padding-right: 10px;
}

.item-controls .item-order a {
	font-weight: bold;
}

.nav-menus-php .item-edit {
	position: absolute;
	right: -20px;
	top: 0;
	display: block;
	width: 30px;
	height: 36px;
	overflow: hidden;
	text-indent:-999em;
	border-bottom: 1px solid;
	-webkit-border-bottom-left-radius: 3px;
	border-bottom-left-radius: 3px;
}

/* Menu editing */
.menu-instructions-inactive {
	display: none;
}

.menu-item-settings {
	display: block;
	width: 400px;
	padding: 10px 0 10px 10px;
	border: solid;
	border-width: 0 1px 1px 1px;
	-webkit-border-bottom-right-radius: 3px;
	-webkit-border-bottom-left-radius: 3px;
	border-bottom-left-radius: 3px;
	border-bottom-right-radius: 3px;
}

.menu-item-edit-active .menu-item-settings {
	display: block;
}

.menu-item-edit-inactive .menu-item-settings {
	display: none;
}

.add-menu-item-pagelinks {
	margin: .5em auto;
	text-align: center;
}

.link-to-original {
	display: block;
	margin: 0 0 10px;
	padding: 3px 5px 5px;
	font-size: 12px;
	font-style: italic;
}

.link-to-original a {
		padding-left: 4px;
		font-style: normal;
}

.hidden-field {
	display: none;
}

.menu-item-settings .description-thin,
.menu-item-settings .description-wide {
	margin-right: 10px;
	float: left;
}

.description-thin {
	width: 190px;
	height: 40px;
}

.description-wide {
	width: 390px;
}

.menu-item-actions {
	padding-top: 15px;
}

#cancel-save {
	cursor: pointer;
}

/* Major/minor publishing actions (classes) */
.nav-menus-php .major-publishing-actions {
	clear: both;
	padding: 3px 0 5px;
}

.nav-menus-php .major-publishing-actions .publishing-action {
	text-align: right;
	float: right;
	line-height: 23px;
	margin: 5px 0 1px;
}

.nav-menus-php .major-publishing-actions .delete-action {
	vertical-align: middle;
	text-align: left;
	float: left;
	padding-right: 15px;
	margin-top: 5px;
}

.menu-name-label span,
.auto-add-pages label {
	font-size: 12px;
	font-style: normal;
}

.menu-name-label {
	margin-right: 15px;
}

.auto-add-pages input {
	margin-top: 0;
}

.auto-add-pages {
	margin-top: 4px;
	float: left;
}

.nav-menus-php .submitbox .submitcancel {
	border-bottom: 1px solid;
	padding: 1px 2px;
	text-decoration: none;
}

.nav-menus-php .major-publishing-actions .form-invalid {
	padding-left: 4px;
	margin-left: -4px;
	border: 0 none;
}

/* Clearfix */
#menu-item-name-wrap:after,
#menu-item-url-wrap:after,
#menu-name-label:after,
#menu-settings-column .inside:after,
#nav-menus-frame:after,
.nav-menus-php #post-body-content:after,
.nav-menus-php .button-controls:after,
.nav-menus-php .major-publishing-actions:after,
.nav-menus-php .menu-item-settings:after {
	clear: both;
	content: ".";
	display: block;
	height: 0;
	visibility: hidden;
}

#nav-menus-frame,
.button-controls,
#menu-item-url-wrap,
#menu-item-name-wrap {
	display: block;
}






/* plugin-install */
/* NOTE: the following CSS rules(.star*) are taken more or less straight from the bbPress rating plugin. */
div.star-holder {
	position: relative;
	height: 19px;
	width: 100px;
	font-size: 19px;
}

div.action-links {
	font-weight: normal;
	margin: 6px 0 0;
}

div.star {
	height: 100%;
	position: absolute;
	top: 0;
	left: 0;
	background-color: transparent;
	letter-spacing: 1ex;
	border: none;
}

.star1 { width: 20%; }
.star2 { width: 40%; }
.star3 { width: 60%; }
.star4 { width: 80%; }
.star5 { width: 100%; }

.star img,
div.star a,
div.star a:hover,
div.star a:visited {
	display: block;
	position: absolute;
	right: 0;
	border: none;
	text-decoration: none;
}

div.star img {
	width: 19px;
	height: 19px;
}

/* Header on thickbox */
#plugin-information-header {
	margin: 0;
	padding: 0 5px;
	font-weight: bold;
	position: relative;
	border-bottom-width: 1px;
	border-bottom-style: solid;
	height: 2.5em;
}
#plugin-information ul#sidemenu {
	font-weight: normal;
	margin: 0 5px;
	position: absolute;
	left: 0;
	bottom: -1px;
}

/* Install sidemenu */
#plugin-information p.action-button {
	width: 100%;
	padding-bottom: 0;
	margin-bottom: 0;
	margin-top: 10px;
	-webkit-border-top-left-radius: 3px;
	-webkit-border-bottom-left-radius: 3px;
	border-top-left-radius: 3px;
	border-bottom-left-radius: 3px;
}

#plugin-information .action-button a {
	text-align: center;
	font-weight: bold;
	text-decoration: none;
	display: block;
	line-height: 2em;
}

#plugin-information h2 {
	clear: none !important;
	margin-right: 200px;
}

#plugin-information .fyi {
	margin: 0 10px 50px;
	width: 210px;
}

#plugin-information .fyi h2 {
	font-size: 0.9em;
	margin-bottom: 0;
	margin-right: 0;
}

#plugin-information .fyi h2.mainheader {
	padding: 5px;
	-webkit-border-top-left-radius: 3px;
	border-top-left-radius: 3px;
}

#plugin-information .fyi ul {
	padding: 10px 5px 10px 7px;
	margin: 0;
	list-style: none;
	-webkit-border-bottom-left-radius: 3px;
	border-bottom-left-radius: 3px;
}

#plugin-information .fyi li {
	margin-right: 0;
}

#plugin-information #section-holder {
	padding: 10px;
}

#plugin-information .section ul,
#plugin-information .section ol {
	margin-left: 16px;
	list-style-type: square;
	list-style-image: none;
}

#plugin-information #section-screenshots li img {
	vertical-align: text-top;
}

#plugin-information #section-screenshots li p {
	font-style: italic;
	padding-left: 20px;
	padding-bottom: 2em;
}

#plugin-information .updated,
#plugin-information pre {
	margin-right: 215px;
}

#plugin-information pre {
	padding: 7px;
	overflow: auto;
}



/* press-this */
body.press-this {
	color: #333;
	margin: 0;
	padding: 0;
	min-width: 675px;
	min-height: 400px;
}

img {
	border: none;
}

/* Header */
.press-this #wphead {
	height: 32px;
	margin-right: 5px;
	margin-bottom: 5px;
}

.press-this #header-logo {
	float: left;
	margin: 7px 7px 0;
	-webkit-user-select: none;
	-moz-user-select: none;
	user-select: none;
}

.press-this-sidebar {
	float: right;
	width: 200px;
	padding-top: 10px;
}

.press-this #title {
	-moz-box-sizing: border-box;
	-webkit-box-sizing: border-box;
	-ms-box-sizing: border-box;
	box-sizing: border-box;
}

.press-this #wphead h1 {
	padding: 6px 0 0;
	font-weight: normal;
}

.press-this #wphead h1 a {
	text-decoration: none;
}

.press-this #wphead h1 a:hover {
	text-decoration: underline;
}

.press-this .tagchecklist span a {
	background: transparent url(../images/xit.gif) no-repeat 0 0;
}

.press-this #titlediv {
	margin: 0;
}

.press-this .wp-media-buttons {
	cursor: default;
	padding: 8px 8px 0;
}

.press-this #submitpost #ajax-loading,
.press-this #submitpost .ajax-loading {
	vertical-align: middle;
}

.press-this .howto {
	margin-top: 2px;
	margin-bottom: 3px;
	font-size: 12px;
	font-style: italic;
	display: block;
}

.press-this input.text {
	outline-color: -moz-use-text-color;
	outline-style: none;
	outline-width: medium;
	width: 100%;
}

/* Editor/Main Column */
.press-this #poststuff {
	margin: 0 10px 10px;
}

#poststuff #editor-toolbar {
	height: 30px;
}

div.zerosize {
	border: 0 none;
	height: 0;
	margin: 0;
	overflow: hidden;
	padding: 0;
	width: 0;
}

.posting {
	margin-right: 212px;
	position: relative;
}

.press-this .inner-sidebar {
	width: 200px;
}

.press-this .inner-sidebar .sleeve {
	padding-top: 5px;
}

.press-this #submitdiv .inside {
	margin: 0;
}

.press-this #submitdiv p {
	margin: 6px;
    padding: 0 0 6px;
	-webkit-box-shadow: 0 1px 0 #fff;
	-moz-box-shadow: 0 1px 0 #fff;
	box-shadow: 0 1px 0 #fff;
}

.press-this #submitdiv #publishing-actions {
	border-bottom: 1px solid #dfdfdf;
}

.press-this #publish {
	float: right;
}

.press-this #poststuff h2,
.press-this #poststuff h3 {
	font-size: 13px;
	line-height: 1;
}

.press-this #tagsdiv-post_tag h3,
.press-this #categorydiv h3 {
	cursor: pointer;
}

.press-this #submitdiv h3 {
	cursor: default;
}

h3.tb {
	text-shadow: 0 1px 0 #fff;
	font-weight: bold;
	font-size: 12px;
	margin-left: 5px;
}

#TB_window {
	border: 1px solid #333;
}

.press-this .postbox,
.press-this .stuffbox {
	margin-bottom: 10px;
	min-width: 0;
}

.postbox:hover .handlediv,
.stuffbox:hover .handlediv {
	background: transparent url(../images/arrows.png) no-repeat 6px 7px;
}

.tbtitle {
	font-size: 1.7em;
	outline: none;
	padding: 3px 4px;
	border-color: #dfdfdf;
}

.press-this .actions {
	float: right;
	margin: -19px 0 0;
}

.press-this #extra-fields .actions {
	margin: -23px -7px 0 0;
}

.press-this .actions li {
	float: left;
	list-style: none;
	margin-right: 10px;
}

#extra-fields .button {
	margin-right: 5px;
}

/* Photo Styles */
#photo_saving {
	margin: 0 8px 8px;
	vertical-align: middle;
}

#img_container_container {
	overflow: auto;
}

#extra-fields {
	margin-top: 10px;
	position: relative;
}

#waiting {
	margin-top: 10px;
}

#extra-fields .postbox {
	margin-bottom: 5px;
}

#extra-fields .titlewrap {
	padding: 0;
	overflow: auto;
	height: 100px;
}

#img_container a {
	display: block;
	float: left;
	overflow: hidden;
	vertical-align: center;
}

#img_container img,
#img_container a {
	width: 68px;
	height: 68px;
}

#img_container img {
	border: none;
	background-color: #f4f4f4;
	cursor: pointer;
}

#img_container a,
#img_container a:link,
#img_container a:visited {
	border: 1px solid #ccc;
	display: block;
	position: relative;
}

#img_container a:hover,
#img_container a:active {
	border-color: #000;
	z-index: 1000;
	border-width: 2px;
	margin: -1px;
}

/* Video */
#embed-code {
	width: 100%;
	height: 98px;
}

/* Categories */
.press-this .category-add input[type="text"],
.press-this .category-add select {
	width: 100%;
	margin: 1px;
}

.press-this .categorydiv div.tabs-panel {
	height: 100px;
	overflow: auto;
	padding: 0.5em 0.9em;
	border-style: solid;
	border-width: 1px;
}

.press-this .category-tabs li {
	display: inline;
}

.press-this .category-tabs a {
	text-decoration: none;
}

.press-this ul.category-tabs {
	margin-bottom: 5px;
	padding-top: 8px;
}

/* Tags */
.press-this .tagsdiv .newtag {
	margin-right: 5px;
	width: auto;
}

.jaxtag {
	clear: both;
	margin: 0;
}

.tagadd {
	margin-left: 3px;
}

.press-this .tagchecklist {
	margin-top: 3px;
	margin-bottom: 1em;
	font-size: 12px;
	overflow: auto;
}

.press-this .tagchecklist strong {
	position: absolute;
	font-size: .75em;
}

.press-this .tagchecklist span {
	margin-right: .5em;
	margin-left: 10px;
	display: block;
	float: left;
	font-size: 12px;
	line-height: 1.8em;
	white-space: nowrap;
	cursor: default;
}

.press-this #content {
	margin: 5px 0;
	padding: 0 5px;
	border: 0 none;
	height: 357px;
	font-family: Consolas, Monaco, monospace;
	font-size: 13px;
	line-height: 19px;
	background: transparent;
}

/* Submit */
#saving {
	display: inline;
	vertical-align: middle;
}

#TB_ajaxContent #options {
	position: absolute;
	top: 20px;
	right: 25px;
	padding: 5px;
}

#TB_ajaxContent h3 {
	margin-bottom: .25em;
}

.error a {
	text-decoration: underline;
}

.updated a {
	text-decoration: none;
	padding-bottom: 2px;
}

/* tag hints */
.taghint {
	color: #aaa;
	margin: -17px 0 0 7px;
	visibility: hidden;
}

input.newtag ~ div.taghint {
	visibility: visible;
}

input.newtag:focus ~ div.taghint {
	visibility: hidden;
}

/* TinyMCE */
#mce_fullscreen_container {
	background: #fff;
}

#photo-add-url-div input[type="text"] {
	width: 300px;
}





/* theme-editor */
.alignleft h3 {
	margin: 0;
}

h3 span {
	font-weight: normal;
}

#template textarea {
	font-family: Consolas, Monaco, monospace;
	font-size: 12px;
	width: 97%;
	background: #f9f9f9;
	outline: none;
}

#template p {
	width: 97%;
}

#templateside {
	float: right;
	width: 190px;
	word-wrap: break-word;
}

#templateside h3,
#postcustomstuff p.submit {
	margin: 0;
}

#templateside h4 {
	margin: 1em 0 0;
}

#templateside ol,
#templateside ul {
	margin: .5em;
	padding: 0;
}

#templateside li {
	margin: 4px 0;
}

#templateside ul li a span.highlight {
	display:block;
}

.nonessential {
	font-size: 11px;
	font-style: italic;
	padding-left: 12px;
}

.highlight {
	padding: 3px 3px 3px 12px;
	margin-left: -12px;
	font-weight: bold;
	border: 0 none;
}

#documentation {
	margin-top: 10px;
}
#documentation label {
	line-height: 22px;
	vertical-align: top;
	font-weight: bold;
}

.fileedit-sub {
	padding: 10px 0 8px;
	line-height: 180%;
}






/* theme-install */
.theme-listing .theme-item {
	display: inline-block;
	width: 200px;
	border: thin solid #ccc;
	vertical-align: top;
}

.theme-listing .theme-item h3 {
	text-align: center;
	font-size: 14px;
	font-style: italic;
	margin: 0;
	padding: 0;
}

.theme-listing .theme-item img {
	max-width: 150px;
	max-height: 150px;
}

.theme-listing .theme-item-info span {
	display: none;
}

.theme-listing .theme-item:hover .theme-item-info span {
	display: inline;
}

.theme-listing .theme-item:hover .theme-item-info span.dots {
	display: none;
}

.theme-listing .theme-item-info span.action-links {
	font-weight: bold;
	text-align: center;
}

.theme-listing br.line {
	border-bottom-width: 1px;
	border-bottom-style: solid;
	margin-bottom: 3px;
}

.available-theme {
	padding: 20px 15px;
}

#theme-information .available-theme {
	overflow: visible;
	padding: 20px 15px;
	width: 440px;
}

#theme-information .theme-preview-img {
	float: left;
	margin: 5px 25px 10px 15px;
	width: 300px;
}

#theme-information .action-button {
	border-top-width: 1px;
	border-top-style: solid;
	margin: 10px 5px 0;
}

#theme-information .action-button #cancel {
	float: left;
	margin: 10px 15px;
}

#theme-information .action-button #install {
	float: right;
	margin: 10px 15px;
}

#theme-information .available-theme h3 {
	margin: 1em 0;
}

body#theme-information {
	height: auto;
}

.feature-filter {
	padding: 8px 12px 0;
}

.feature-filter .feature-group {
	float: left;
	margin: 5px 10px 10px;
}

.feature-filter .feature-name {
	font-weight: bold;
}

.feature-filter .feature-group li {
	display: inline;
	float: left;
	list-style-type: none;
	padding-right: 25px;
	min-width: 150px;
}

.feature-container {
width: 100%;
overflow: auto;
margin-bottom: 10px;
}




/* widgets */

/* 2 column liquid layout */
div.widget-liquid-left {
	float: left;
	clear: left;
	width: 100%;
	margin-right: -325px;
}

div#widgets-left {
	margin-left: 5px;
	margin-right: 325px;
}

div#widgets-right {
	width: 285px;
	margin: 0 auto;
}

div.widget-liquid-right {
	float: right;
	clear: right;
	width: 300px;
}

.widget-liquid-right .widget,
.inactive-sidebar .widget,
.widget-liquid-right .sidebar-description {
	width: 250px;
	margin: 0 auto 20px;
	overflow: hidden;
}

.widget-liquid-right .sidebar-description {
	margin-bottom: 10px;
}

.inactive-sidebar .widget {
	margin: 0 10px 20px;
	float: left;
}

div.sidebar-name h3 {
	font-weight: normal;
	font-size: 15px;
	margin: 0;
	padding: 8px 10px;
	overflow: hidden;
	white-space: nowrap;
}

div.sidebar-name {
	cursor: pointer;
	font-size: 13px;
	border-width: 1px;
	border-style: solid;
	-webkit-border-top-right-radius: 3px;
	-webkit-border-top-left-radius: 3px;
	border-top-right-radius: 3px;
	border-top-left-radius: 3px;
}

.js .closed .sidebar-name {
	-webkit-border-bottom-right-radius: 3px;
	-webkit-border-bottom-left-radius: 3px;
	border-bottom-right-radius: 3px;
	border-bottom-left-radius: 3px;
}

.widget-liquid-right .widgets-sortables,
#widgets-left .widget-holder {
	border-width: 0 1px 1px;
	border-style: none solid solid;
	-webkit-border-bottom-right-radius: 3px;
	-webkit-border-bottom-left-radius: 3px;
	border-bottom-right-radius: 3px;
	border-bottom-left-radius: 3px;
}

.js .closed .widgets-sortables,
.js .closed .widget-holder {
	display: none;
}

.widget-liquid-right .widgets-sortables {
	padding: 15px 0 0;
}

#available-widgets .widget-holder {
	padding: 7px 5px 0;
}

#available-widgets .widget {
	-moz-box-shadow: none;
	-webkit-box-shadow: none;
	box-shadow: none;
}

.inactive-sidebar {
	padding: 5px 5px 0;
}

#widget-list .widget {
	width: 250px;
	margin: 0 10px 15px;
	border: 0 none;
	background: transparent;
	float: left;
}

#widget-list .widget-description {
	padding: 5px 8px;
}

.widget-placeholder {
	border-width: 1px;
	border-style: dashed;
	margin: 0 auto 20px;
	height: 26px;
	width: 250px;
}

.inactive-sidebar .widget-placeholder {
	margin: 0 10px 20px;
	float: left;
}

div.widgets-holder-wrap {
	padding: 0;
	margin: 10px 0 20px;
}

#widgets-left #available-widgets {
	background-color: transparent;
	border: 0 none;
}

ul#widget-list {
	list-style: none;
	margin: 0;
	padding: 0;
	min-height: 100px;
}

.widget .widget-top {
	margin-bottom: -1px;
	font-size: 12px;
	font-weight: bold;
	height: 26px;
	overflow: hidden;
}

.widget-top .widget-title {
	padding: 7px 9px;
}

.widget-top .widget-title-action {
	float: right;
}

a.widget-action {
	display: block;
	width: 24px;
	height: 26px;
}

#available-widgets a.widget-action {
	display: none;
}

.widget-top a.widget-action {
	background: transparent url(../images/arrows.png) no-repeat 4px 6px;
}

.widget-top a.widget-action:hover {
	background: transparent url(../images/arrows-dark.png) no-repeat 4px 6px;
}

.widget .widget-inside,
.widget .widget-description {
	padding: 12px 12px 10px;
	font-size: 12px;
	line-height: 16px;
}

.widget-inside,
.widget-description {
	display: none;
}

#available-widgets .widget-description {
	display: block;
}

.widget .widget-inside p {
	margin: 0 0 1em;
	padding: 0;
}

.widget-title h4 {
	margin: 0;
	line-height: 1;
	overflow: hidden;
	white-space: nowrap;
}

.widgets-sortables {
	min-height: 90px;
}

.widget-control-actions {
	margin-top: 8px;
}

.widget-control-actions a {
	text-decoration: none;
}

.widget-control-actions a:hover {
	text-decoration: underline;
}

.widget-control-actions .ajax-feedback {
	padding-bottom: 3px;
}

.widget-control-actions div.alignleft {
	margin-top: 6px;
}

div#sidebar-info {
	padding: 0 1em;
	margin-bottom: 1em;
	font-size: 12px;
}

.widget-title a,
.widget-title a:hover {
	text-decoration: none;
	border-bottom: none;
}

.widget-control-edit {
	display: block;
	font-size: 12px;
	font-weight: normal;
	line-height: 26px;
	padding: 0 8px 0 0;
}

a.widget-control-edit {
	text-decoration: none;
}

.widget-control-edit .add,
.widget-control-edit .edit {
	display: none;
}

#available-widgets .widget-control-edit .add,
#widgets-right .widget-control-edit .edit,
.inactive-sidebar .widget-control-edit .edit {
	display: inline;
}

.editwidget {
	margin: 0 auto 15px;
}

.editwidget .widget-inside {
	display: block;
	padding: 10px;
}

.inactive p.description {
	margin: 5px 15px 10px;
}

#available-widgets p.description {
	margin: 0 12px 12px;
}

.widget-position {
	margin-top: 8px;
}

.inactive {
	padding-top: 2px;
}

.sidebar-name-arrow {
	float: right;
	height: 29px;
	width: 26px;
}

.widget-title .in-widget-title {
	font-size: 12px;
	white-space: nowrap;
}

#removing-widget {
	display: none;
	font-weight: normal;
	padding-left: 15px;
	font-size: 12px;
	line-height: 1;
}

.widget-control-noform,
#access-off,
.widgets_access .widget-action,
.widgets_access .sidebar-name-arrow,
.widgets_access #access-on,
.widgets_access .widget-holder .description {
	display: none;
}

.widgets_access .widget-holder,
.widgets_access #widget-list {
	padding-top: 10px;
}

.widgets_access #access-off {
	display: inline;
}

.widgets_access #wpbody-content .widget-title-action,
.widgets_access #wpbody-content .widget-control-edit,
.widgets_access .closed .widgets-sortables,
.widgets_access .closed .widget-holder {
	display: block;
}

.widgets_access .closed .sidebar-name {
	-webkit-border-bottom-right-radius: 0;
	-webkit-border-bottom-left-radius: 0;
	border-bottom-right-radius: 0;
	border-bottom-left-radius: 0;
}

.widgets_access .sidebar-name,
.widgets_access .widget .widget-top {
	cursor: default;
}

/* =Media Queries
-------------------------------------------------------------- */

@media only screen and (max-width: 768px) {
	/* categories */
	#col-left {
		width: 100%;
	}

	#col-right {
		width: 100%;
	}
}

@media only screen and (min-width: 769px) {
	/* categories */
	#col-left {
		width: 35%;
	}

	#col-right {
		width: 65%;
	}
}

@media only screen and (max-width: 860px) {

	/* categories */
	#col-left {
		width: 35%;
	}

	#col-right {
		width: 65%;
	}
}

@media only screen and (min-width: 980px) {

	/* categories */
	#col-left {
		width: 35%;
	}

	#col-right {
		width: 65%;
	}
}

@media only screen and (max-width: 768px) {
	/* categories */
	#col-left {
		width: 100%;
	}

	#col-right {
		width: 100%;
	}

	.form-field input,
	.form-field textarea {
		width: 99%;
	}

	.form-wrap .form-field {
		padding:0;
	}

	/* users */
	#profile-page .form-table textarea {
		max-width: 400px;
		width: auto;
	}
}
